<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Controllers\Interfaces\StatusInterface;
use App\Http\Requests\Front\LeadRequest;
use App\Services\LeadService;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Models\Lead;
use App\Models\Country;
use App\Models\Province;
use App\Models\Via;
use App\Models\Variant;
use App\Models\Periodicity;
use App\Models\Campaign;
use Exception;
use App\Exceptions\GeneralException;
use Illuminate\Validation\ValidationException;
use Throwable;

class BackOfficeController extends Controller implements StatusInterface
{

            /**
     * @var LeadService
     */
    protected $leadService;


    /**
     * LeadService constructor.
     *
     * @param  LeadService  $leadService
     *
     */
    public function __construct(LeadService $leadService)
    {
        $this->leadService = $leadService;
    }



    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $leads = Lead::where('closed', 0)->paginate(10);
        return view('backend.pages.bo.index', ['leads' => $leads]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $lead = Lead::where('id', $id)->first();

        $client = $lead->myClient;
        $address = $client->address;
        $leadLine = $lead->myLeadLines()->first();
        $variant =  $leadLine->variant;
        $periodicity = $leadLine->periodicity;
        $campaign = $leadLine->campaign;


        $countries = Country::all();
        $vias = Via::all();
        $provinces = Province::all();
        $variants = Variant::all();
        $periodicities = Periodicity::all();
        if ($countries->isEmpty()) {
            $countries = null;
        }
        if ($vias->isEmpty()) {
            $vias = null;
        }
        if ($provinces->isEmpty()) {
            $provinces = null;
        }
        if ($variants->isEmpty()) {
            $variants = null;
        }
        if ($periodicities->isEmpty()) {
            $periodicities = null;
        }


        if ($lead) {
            return view('backend.pages.bo.form', ['lead' => $lead, 'client' => $client,
            'leadLine' => $leadLine, 'address' => $address,
            'countries' => $countries, 'vias' => $vias, 'provinces' => $provinces,
            'variants' => $variants, 'variant' => $variant,
            'periodicity' => $periodicity, 'periodicities' => $periodicities,
            'campaign' => $campaign]);
        } else {
            return redirect()->back()->withFlashDanger(__('auth.general_error'));
        }
    }

    /**
     * Update a newly created resource in storage.
     *
     * @param LeadRequest $request
     * @return \Illuminate\Http\RedirectResponse
     * @throws GeneralException
     */
    public function update(LeadRequest $request): \Illuminate\Http\RedirectResponse
    {
        //
        $validator = null;
        try {
            if (isset($request->validator)) {
                $validator = $request->validator;
            }
            if (!(isset($validator) && $validator->fails())) {
                if (isset($errors['status'])) {
                    throw new GeneralException($errors['message']);
                }
                $lead = $this->leadService->updateLead($request);
                if ($lead){
                    return redirect()->route('admin.bo.bo.index')->withFlashSuccess(__('backend.alert.success'));
                }
            }
        } catch (ValidationException $e) {
            return back()->withErrors($e->getMessage())->withInput();
        } catch (Exception | Throwable $e) {
            Log::error($e);
            throw new GeneralException($e->getMessage());
        }
        return redirect()->route('admin.bo.bo.index')->withErrors(__('auth.general_error'))->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
