<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use App\Services\HelperService;
use Illuminate\Support\Collection;
use Illuminate\Http\Request;
use Carbon\Carbon;
use DataTables;
use Illuminate\Support\Facades\Log;
use App\Services\CompanyLinkService;
use App\Models\CompanyLink;
use App\Http\Requests\Backend\CompanyLinkRequest;

class CompanyLinkController extends Controller implements StatusInterface
{
    /**
     * @var CompanyLinkService
     */
    protected $companyLinkService;


    /**
     * CompanyController constructor.
     *
     * @param  CompanyLinkService  $companyLinkService
     *
     */
    public function __construct(CompanyLinkService $companyLinkService)
    {
        $this->companyLinkService = $companyLinkService;
    }


    /**
     * Display a listing of the resource.
     *
     * @param Request $request
     * @return \Illuminate\Http\Response
     */
    public function jsonList(Request $request)
    {
        if($request->ajax()){
            $data = new Collection;

            $param = $request->all();
            if (isset($param['companyId']) && $param['companyId']> 0) {
                $companyLinks = CompanyLink::where('company_id', $param['companyId'])->get();
            } else {
                $companyLinks = CompanyLink::all();
            }
            foreach($companyLinks as $companyLink) {
                $data->push([
                    'id'         => $companyLink->id,
                    'name'       => $companyLink->name,
                    'url'        => $companyLink->url,
                    'active'     => $companyLink->active,
                    'diff'       => Carbon::parse($companyLink->created_at)->diffForHumans(),
                ]);
            }

            if ($companyLinks) {
                return DataTables::of($data)
                ->addColumn('action', function($data){

                    $id = isset($data['id']) ? $data['id'] : -1;
                    $routeShow =  route('admin.auth.company-link.company-link.show', ['link' => $id]);
                    $routeDelete = route('admin.auth.company-link.company-link.delete', ['link' => $id]);
                    return '<a view="'.$routeShow.'" type="button" name="view" class="btn btn-info btn-sm view"><i class="fas fa-search"> '.trans('backend.button.view').'</i></a>
                    <button attr-delete="'.$routeDelete.'" type="button" name="delete" attr-id="'.$id.'"  class="btn btn-danger btn-sm delete"><i class="fas fa-trash"> '.trans('backend.button.delete').'</i></button>';
                })
                ->addColumn('active-icon', function($data){
                    return HelperService::getYesNoIconTable($data['active']);
                })
                ->rawColumns(['action', 'active-icon'])
                ->make(true);
            }
        }
        return DataTables::of(new Collection);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param CompanyLinkRequest $request
     * @return \Illuminate\Http\Response
     */
    public function create(CompanyLinkRequest $request)
    {
        $data = self::KO;

        if($request->ajax()){
            $formData = $request->all();
            if ($this->companyLinkService->create($formData)) {
                $data = ['success' => self::OK];
            }
        }
        return response()->json(json_encode($data, true));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param CompanyLinkRequest $request
     * @return \Illuminate\Http\Response
     */
    public function store(CompanyLinkRequest $request)
    {
        $data = self::KO;

        if($request->ajax()){
            $formData = $request->all();
            if (isset($formData['company-link-id']) && $formData['company-link-id'] > 0) {
                //Update
                $companyLink = CompanyLink::where('id', $formData['company-link-id'])->first();
                if ($companyLink) {
                    if ($this->companyLinkService->update($companyLink, $formData)) {
                        $data = ['success' => self::OK];
                    }
                } else {
                    //Create
                    return $this->create($request);
                }
            } else {
                //Create
                return $this->create($request);
            }
        }
        return response()->json(json_encode($data, true));
    }

    /**
     * Display the specified resource.
     * @param Request $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Request $request, $id)
    {
        $companyLink = null;
        if($request->ajax())
        {
            $data = CompanyLink::where('id', $id)->first();
            if ($data) {
                $companyLink = $data->toArray();
            }
        }
        return response()->json(json_encode($companyLink, true));
    }

    /**
     * @param $id
     */
    public function edit($id)
    {
        //

    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param $companyLinkId
     * @return \Illuminate\Http\Response
     */
    public function delete($companyLinkId)
    {
        $data = self::KO;
        $companyLink = CompanyLink::where('id', $companyLinkId)->first();
        if ($companyLink) {
            if ($this->companyLinkService->delete($companyLink)) {
                $data = ['success' => self::OK];
            }
        }
        return response()->json(json_encode($data, true));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param $companyId
     * @return \Illuminate\Http\Response
     */
    public function destroy($companyId)
    {
        $data = self::KO;
        $companyLink = CompanyLink::where('id', $companyId)->first();
        if ($companyLink) {
            if ($this->companyLinkService->destroy($companyLink)) {
                $data = ['success' => self::OK];
            }
        }
        return response()->json(json_encode($data, true));
    }
}
