<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use Illuminate\Http\Request;
use  App\Http\Requests\Backend\RegisterSearchRequest;
use App\Models\Register;
use App\Models\RegisterState;
use App\Services\RegisterService;
use Illuminate\Support\Facades\Log;
use Exception;
use Illuminate\Validation\ValidationException;
use Throwable;

class HourController extends Controller implements StatusInterface
{
    /**
     * @var RegisterService
     */
    private $registerService;

    /**
     * HourController constructor.
     *
     * @param  RegisterService  $registerService
     *
     */
    public function __construct(RegisterService $registerService)
    {
        $this->registerService = $registerService;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View|\Illuminate\Http\Response
     */
    public function index()
    {
        return view('backend.pages.hour.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View|\Illuminate\Http\Response
     */
    public function show($id)
    {
        $registerState = RegisterState::where('id', $id)->first();
        $registers = $registerState->registers;
        if ($registerState) {
            return view('backend.pages.hour.show', ['registerState' => $registerState, 'registers' => $registers]);
        } else {
            return redirect()->back()->withFlashDanger(__('auth.general_error'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    /**
     * Search
     * @param RegisterSearchRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function search(RegisterSearchRequest $request)
    {
         //
         $data = self::ERROR;

         if($request->ajax()){
             try {
                 if (isset($request->validator)) {
                     $validator = $request->validator;
                 }
                 if (!(isset($validator) && $validator->fails())) {
                    $data = $this->registerService->getJsonList($request);
                 }
             } catch (ValidationException $e) {
                $data = [self::ERROR => $e->getMessage()];
             } catch (Exception | Throwable $e) {
                Log::error($e);
                $data = [self::ERROR => __('auth.general_error')];
             }
         }

         return response()->json(json_encode($data, true));
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function process(Request $request) {
        //
        $data = self::ERROR;
        $validator = null;
        try {
            if($request->ajax()){
                $data = $this->registerService->stateRegister($request);
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }

     /**
     * Localize
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
      */
    public function localize(Request $request): \Illuminate\Http\JsonResponse
    {
         //
         $data = self::ERROR;

         if($request->ajax()){
             try {
                 if (isset($request->validator)) {
                     $validator = $request->validator;
                 }
                 if (!(isset($validator) && $validator->fails())) {
                    $data = $this->registerService->getLocalization($request);
                 }
             } catch (ValidationException $e) {
                $data = [self::ERROR => $e->getMessage()];
             } catch (Exception | Throwable $e) {
                Log::error($e);
                $data = [self::ERROR => __('auth.general_error')];
             }
         }

         return response()->json(json_encode($data, true));
    }

}
