<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Interfaces\StatusInterface;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Lopd;
use App\Services\LopdService;
use App\Http\Requests\Backend\LopdRequest;
use Illuminate\Support\Facades\Log;
use Exception;
use App\Exceptions\GeneralException;
use Illuminate\Validation\ValidationException;
use Throwable;

class LopdController extends Controller implements StatusInterface
{

        /**
     * @var LopdService
     */
    protected $lopdService;


    /**
     * LopdController constructor.
     *
     * @param  LopdService  $lopdService
     *
     */
    public function __construct(LopdService $lopdService)
    {
        $this->lopdService = $lopdService;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $lopds = Lopd::orderBy('active', 'desc')->paginate(10);
        return view('backend.pages.lopd.index', ['lopds' => $lopds]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('backend.pages.lopd.form');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param LopdRequest $request
     * @return \Illuminate\Http\RedirectResponse
     * @throws \App\Exceptions\GeneralException
     * @throws \Throwable
     */
    public function store(LopdRequest $request)
    {
        //
        $validator = null;
        try {
            if (isset($request->validator)) {
                $validator = $request->validator;
            }
            if (!(isset($validator) && $validator->fails())) {
                $lopd = $this->lopdService->createLopd($request);
                if ($lopd){
                    return redirect()->route('admin.auth.lopd.lopd.index')->withFlashSuccess(__('backend.alert.success'));
                }
            }
        } catch (ValidationException $e) {
            return back()->withErrors($e->getMessage())->withInput();
        } catch (Exception | Throwable $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View|\Illuminate\Http\Response
     */
    public function edit($id)
    {
        $lopd = Lopd::where('id', $id)->first();
        if ($lopd) {
            return view('backend.pages.lopd.form', ['lopd' => $lopd]);
        } else {
            return redirect()->back()->withFlashDanger(__('auth.general_error'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param LopdRequest $request
     * @return \Illuminate\Http\RedirectResponse
     * @throws \App\Exceptions\GeneralException
     * @throws \Throwable
     */
    public function update(LopdRequest $request)
    {
        //
        $validator = null;
        try {
            if (isset($request->validator)) {
                $validator = $request->validator;
            }
            if (!(isset($validator) && $validator->fails())) {

                $lopd = $this->lopdService->updateLopd($request);
                if ($lopd){
                    return redirect()->route('admin.auth.lopd.lopd.index')->withFlashSuccess(__('backend.alert.success'));
                }
            }
        } catch (ValidationException $e) {
            throw new ValidationException($e->getMessage());
        } catch (Exception | Throwable $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
        }
        return redirect()->route('admin.auth.lopd.lopd.index')->withErrors(__('auth.general_error'))->withInput();
    }

     /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\JsonResponse
      */
    public function delete($id)
    {
        //
        $data = self::KO;
        $lopd = Lopd::where('id', $id)->first();
        if ($lopd) {
            if ($this->lopdService->delete($lopd)) {
                $data = ['success' => self::OK];
            }
        }
        return response()->json(json_encode($data, true));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\JsonResponse
     */
    public function destroy($id)
    {
        //
        $data = self::KO;
        $lopd = Lopd::where('id', $id)->first();
        if ($lopd) {
            if ($this->lopdService->destroy($lopd)) {
                $data = ['success' => self::OK];
            }
        }
        return response()->json(json_encode($data, true));
    }
}
