<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use Illuminate\Http\Request;
use App\Services\MasterService;
use App\Http\Requests\Backend\MasterRequest;
use Illuminate\Support\Facades\Log;
use App\Models\Master;
use Exception;
use Illuminate\Validation\ValidationException;
use Throwable;

class MasterController extends Controller implements StatusInterface
{
    /**
     * @var MasterService
     */
    private $masterService;


    /**
     * MasterController constructor.
     *
     * @param  MasterService  $masterService
     *
     */
    public function __construct(MasterService $masterService)
    {
        $this->masterService = $masterService;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('backend.pages.master.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param MasterRequest $request
     * @return \Illuminate\Http\Response
     */
    public function store(MasterRequest $request)
    {
        //
        $data = self::ERROR;

        if($request->ajax()){
            try {
                if (isset($request->validator)) {
                    $validator = $request->validator;
                }
                if (!(isset($validator) && $validator->fails())) {
                    $data = $this->masterService->saveEntity($request);
                }
            } catch (ValidationException $e) {
                $data = [self::ERROR => $e->getMessage()];
            } catch (Exception | Throwable $e) {
                Log::error($e);
                $data = [self::ERROR => __('auth.general_error')];
            }
        }

        return response()->json(json_encode($data, true));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param MasterRequest $request
     * @return \Illuminate\Http\Response
     */
    public function search(MasterRequest $request)
    {
        //
        $data = self::ERROR;

        if($request->ajax()){
            try {
                if (isset($request->validator)) {
                    $validator = $request->validator;
                }
                if (!(isset($validator) && $validator->fails())) {
                    $data = $this->masterService->getEntity($request);
                }
            } catch (ValidationException $e) {
                $data = [self::ERROR => $e->getMessage()];
            } catch (Exception | Throwable $e) {
                Log::error($e);
                $data = [self::ERROR => __('auth.general_error')];
            }
        }

        return response()->json(json_encode($data, true));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return \Illuminate\Http\Response
     */
    public function companies(Request $request)
    {
        //
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
