<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use App\Http\Requests\Backend\MessageRequest;
use App\Services\MessageService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Exception;
use Throwable;

class MessageController extends Controller implements StatusInterface
{
    /**
     * @var MessageService
     */
    private $messageService;

    /**
     * HourController constructor.
     *
     * @param MessageService $messageService
     */
    public function __construct(MessageService $messageService)
    {
        $this->messageService = $messageService;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View|\Illuminate\Http\Response
     */
    public function index()
    {
        //
        return view('backend.pages.message.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

        /**
     * Search
     * @param MessageRequest $request
     * @return \Illuminate\Http\JsonResponse
         */
    public function search(MessageRequest $request)
    {
         //
         $data = self::ERROR;

         if($request->ajax()){
             try {
                 if (isset($request->validator)) {
                     $validator = $request->validator;
                 }
                 if (!(isset($validator) && $validator->fails())) {
                    $data = $this->messageService->getJsonList($request);
                 }
             } catch (ValidationException $e) {
                $data = [self::ERROR => $e->getMessage()];
             } catch (Exception | Throwable $e) {
                Log::error($e);
                $data = [self::ERROR => __('auth.general_error')];
             }
         }

         return response()->json(json_encode($data, true));
    }

    /**
     * Search
     * @param MessageRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function store(MessageRequest $request) {
        //
        $data = self::ERROR;
        $validator = null;
        try {
            if($request->ajax()){
                $data = $this->messageService->send($request);
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }
}
