<?php

namespace App\Http\Controllers\Front;


use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use App\Http\Requests\Backend\CampaignRequest;
use App\Services\CampaignService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Models\Campaign;
use Exception;
use Throwable;

class CampaignController extends Controller implements StatusInterface
{
     /**
     * @var campaignService
     */
    private $campaignService;

    /**
     * HourController constructor.
     *
     * @param CampaignService $campaignService
     */
    public function __construct(CampaignService $campaignService)
    {
        $this->campaignService = $campaignService;
    }
    /**
     * Display a listing of the resource.
     * @param Request $request
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $campaigns = null;
        $user = Auth::User();
        $companyId = null;
        if ($user) {
            $company = $user->myCompany;
            if ($company) {
                $companyId = $company->id;
            }
        }
        $campaigns = Campaign::where([['company_id', $companyId], ['active', 1]])->orWhere('company_id', NULL)->paginate(4);
        $selectedCampaign = $request->session()->get('campaign');
        return view('front.campaign.index', ['campaigns' => $campaigns, 'selectedCampaign' => $selectedCampaign]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Campaign  $campaign
     * @return \Illuminate\Http\Response
     */
    public function show(Campaign $campaign)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Campaign  $campaign
     * @return \Illuminate\Http\Response
     */
    public function edit(Campaign $campaign)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Campaign  $campaign
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Campaign $campaign)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Campaign  $campaign
     * @return \Illuminate\Http\Response
     */
    public function destroy(Campaign $campaign)
    {
        //
    }

         /**
     * @param CampaignRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function change(CampaignRequest $request)
    {
        $data = self::ERROR;
        $validator = null;
        try {
            if($request->ajax()){
                $data = $this->campaignService->change($request);
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }
}
