<?php

namespace App\Http\Controllers\Front;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use App\Http\Requests\Backend\MessageRequest;
use App\Services\MessageService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;
use App\Models\Message;
use Exception;
use Throwable;

class MessageController extends Controller implements StatusInterface
{
    /**
     * @var MessageService
     */
    private $messageService;

    /**
     * HourController constructor.
     *
     * @param MessageService $messageService
     */
    public function __construct(MessageService $messageService)
    {
        $this->messageService = $messageService;
    }

    /**
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $user = Auth::User();
        $messages = $user->messages()->where('read_at', NULL)->paginate(4);
        return view('front.message.index', ['messages' => $messages]);
    }

    /**
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function search(Request $request)
    {
        $data = self::ERROR;
        $validator = null;
        try {
            if($request->ajax()){
                $data = $this->messageService->search($request);
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }


    /**
     * @param $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function show($id)
    {
        $message = Message::where('id', $id)->first();
        $user = Auth::User();
        $messagesUser =  $user->messages()->where('read_at', NULL)->get();
        $found = false;
        foreach($messagesUser as $messageUser) {
            if ($messageUser->id == $message->id) {
                $message->update(['read_at' => now()]);
                $found = true;
            }
        }
        if ($found) {
            return view('front.message.show', ['message' => $message]);
        } else {
            return view('front.home');
        }
    }

     /**
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function delete(Request $request)
    {
        $data = self::ERROR;
        $validator = null;
        try {
            if($request->ajax()){
                $data = $this->messageService->delete($request);
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }
}
