<?php

namespace App\Http\Controllers\Front;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Interfaces\StatusInterface;
use Illuminate\Http\Request;
use App\Http\Requests\Front\RegisterRequest;
use App\Http\Requests\Front\SearchRequest;
use App\Services\RegisterService;
use Exception;
use App\Exceptions\GeneralException;
use Illuminate\Validation\ValidationException;
use Illuminate\Support\Facades\Log;
use Throwable;

class RegisterController extends Controller implements StatusInterface
{
    /**
     * @var RegisterService
     */
    private $registerService;

    /**
     * UserController constructor.
     *
     * @param  RegisterService  $registerService
     *
     */
    public function __construct(RegisterService $registerService)
    {
        $this->registerService = $registerService;
    }


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('front.hour.index');
    }

        /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function manual()
    {
        return view('front.hour.manual');
    }


    /**
     * Show the form for creating a new resource.
     *
     * @param RegisterRequest $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function create(RegisterRequest $request)
    {
        //
        $data = self::KO;
        $validator = null;
        try {
            if($request->ajax()){
                if (isset($request->validator)) {
                    $validator = $request->validator;
                }
                if (!(isset($validator) && $validator->fails())) {
                    $register = $this->registerService->createRegister($request);
                    if ($register){
                        $data = $register;
                    }
                }
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    /**
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function search()
    {
        return view('front.hour.search');
    }


    /**
     * @param SearchRequest $request
     */
    public function find(SearchRequest $request)
    {
        //
        $data = self::KO;
        $validator = null;
        try {
            if($request->ajax()){
                if (isset($request->validator)) {
                    $validator = $request->validator;
                }
                if (!(isset($validator) && $validator->fails())) {
                    $registers = $this->registerService->searchRegister($request);
                    if ($registers){
                        $data = $registers;
                    }
                }
            }
        } catch (Exception | Throwable $e) {
            Log::error($e);
            $data['error'] = __('auth.general_error');
        }
        return response()->json(json_encode($data, true));
    }
}
