<?php

namespace App\Http\Requests\Backend;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Rule;

class UserRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return Auth::User()->isAdmin();
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $data = $this->all();
        if (isset($data['user-id'])) {
            $id = $data['user-id'];
        } else {
            $id = -1;
        }

        return [
            'code' => ['required', 'string', 'max:2'],
            'locale' => ['required', 'string', 'max:2'],
            'username' => ['required', 'string', 'max:50', Rule::unique('users', 'username')->ignore($id)],
            'type' => ['sometimes', 'required'],
            'name' => ['sometimes', 'string', 'max:50'],
            'last_name' => ['sometimes', 'nullable','string', 'max:50'],
            'last_name_2' => ['sometimes', 'nullable','string', 'max:50'],
            'email' => ['required', 'string', 'email', 'max:50',Rule::unique('users', 'email')->ignore($id)],
            'password' => ['sometimes', 'string', 'min:8', 'confirmed'],
            'phone' => ['nullable', 'numeric', 'regex:/^([0-9\s\-\+\(\)]*)$/'],
            'mobile' => ['nullable', 'numeric', 'regex:/^([0-9\s\-\+\(\)]*)$/'],
            'company' => ['required', 'max:150'],
            'team' => ['sometimes', 'nullable', 'max:150'],
            'account' => ['sometimes', 'max:50'],
            'iban' => ['nullable', 'size:4'],
            'avatar' => ['sometimes', 'image', 'max:500000','mimes:jpeg,jpg,png'],
            'active' => ['sometimes'],
            'contract' => ['sometimes', 'required'],
            'contract_hours' => ['sometimes', 'numeric', 'required'],
        ];
    }
}
