<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Announcement\AnnouncementDeleted;
use App\Events\Announcement\AnnouncementCreated;
use App\Events\Announcement\AnnouncementUpdated;
use App\Events\Announcement\AnnouncementDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class AnnouncementEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('Announcement')
            ->performedOn($event->announcement)
            ->log(':causer.name created Announcement :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('Announcement')
            ->performedOn($event->announcement)
            ->log(':causer.name updated Announcement :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('Announcement')
            ->performedOn($event->announcement)
            ->log(':causer.name deleted Announcement :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('Announcement')
            ->performedOn($event->announcement)
            ->log(':causer.name permanently deleted Announcement :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            AnnouncementDeleted::class,
            'App\Listeners\AnnouncementEventListener@onDeleted'
        );


        $events->listen(
            AnnouncementDestroyed::class,
            'App\Listeners\AnnouncementEventListener@onDestroyed'
        );

        $events->listen(
            AnnouncementCreated::class,
            'App\Listeners\AnnouncementEventListener@onCreated'
        );

        $events->listen(
            AnnouncementUpdated::class,
            'App\Listeners\AnnouncementEventListener@onUpdated'
        );
    }
}
