<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Campaign\CampaignDeleted;
use App\Events\Campaign\CampaignCreated;
use App\Events\Campaign\CampaignUpdated;
use App\Events\Campaign\CampaignDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class CampaignEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('Campaign')
            ->performedOn($event->campaign)
            ->log(':causer.name created Campaign :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('Campaign')
            ->performedOn($event->campaign)
            ->log(':causer.name updated Campaign :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('Campaign')
            ->performedOn($event->campaign)
            ->log(':causer.name deleted Campaign :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('Campaign')
            ->performedOn($event->campaign)
            ->log(':causer.name permanently deleted Campaign :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            CampaignDeleted::class,
            'App\Listeners\CampaignEventListener@onDeleted'
        );


        $events->listen(
            CampaignDestroyed::class,
            'App\Listeners\CampaignEventListener@onDestroyed'
        );

        $events->listen(
            CampaignCreated::class,
            'App\Listeners\CampaignEventListener@onCreated'
        );

        $events->listen(
            CampaignUpdated::class,
            'App\Listeners\CampaignEventListener@onUpdated'
        );
    }
}
