<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Company\CompanyDeleted;
use App\Events\Company\CompanyCreated;
use App\Events\Company\CompanyUpdated;
use App\Events\Company\CompanyDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class CompanyEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('company')
            ->performedOn($event->company)
            ->log(':causer.name created company :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('company')
            ->performedOn($event->company)
            ->log(':causer.name updated company :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('company')
            ->performedOn($event->company)
            ->log(':causer.name deleted company :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('company')
            ->performedOn($event->company)
            ->log(':causer.name permanently deleted company :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            CompanyDeleted::class,
            'App\Listeners\CompanyEventListener@onDeleted'
        );


        $events->listen(
            CompanyDestroyed::class,
            'App\Listeners\CompanyEventListener@onDestroyed'
        );

        $events->listen(
            CompanyCreated::class,
            'App\Listeners\CompanyEventListener@onCreated'
        );

        $events->listen(
            CompanyUpdated::class,
            'App\Listeners\CompanyEventListener@onUpdated'
        );
    }
}
