<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Delegation\DelegationDeleted;
use App\Events\Delegation\DelegationCreated;
use App\Events\Delegation\DelegationUpdated;
use App\Events\Delegation\DelegationDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class DelegationEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('delegation')
            ->performedOn($event->delegation)
            ->log(':causer.name created Delegation :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('delegation')
            ->performedOn($event->delegation)
            ->log(':causer.name updated Delegation :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('delegation')
            ->performedOn($event->delegation)
            ->log(':causer.name deleted Delegation :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('delegation')
            ->performedOn($event->delegation)
            ->log(':causer.name permanently deleted Delegation :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            DelegationDeleted::class,
            'App\Listeners\DelegationEventListener@onDeleted'
        );


        $events->listen(
            DelegationDestroyed::class,
            'App\Listeners\DelegationEventListener@onDestroyed'
        );

        $events->listen(
            DelegationCreated::class,
            'App\Listeners\DelegationEventListener@onCreated'
        );

        $events->listen(
            DelegationUpdated::class,
            'App\Listeners\DelegationEventListener@onUpdated'
        );
    }
}
