<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Lead\LeadDeleted;
use App\Events\Lead\LeadCreated;
use App\Events\Lead\LeadUpdated;
use App\Events\Lead\LeadDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class LeadEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('Lead')
            ->performedOn($event->lead)
            ->log(':causer.name created Lead :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('Lead')
            ->performedOn($event->lead)
            ->log(':causer.name updated Lead :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('Lead')
            ->performedOn($event->lead)
            ->log(':causer.name deleted Lead :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('Lead')
            ->performedOn($event->lead)
            ->log(':causer.name permanently deleted Lead :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            LeadDeleted::class,
            'App\Listeners\LeadEventListener@onDeleted'
        );


        $events->listen(
            LeadDestroyed::class,
            'App\Listeners\LeadEventListener@onDestroyed'
        );

        $events->listen(
            LeadCreated::class,
            'App\Listeners\LeadEventListener@onCreated'
        );

        $events->listen(
            LeadUpdated::class,
            'App\Listeners\LeadEventListener@onUpdated'
        );
    }
}
