<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Lopd\LopdDeleted;
use App\Events\Lopd\LopdCreated;
use App\Events\Lopd\LopdUpdated;
use App\Events\Lopd\LopdDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class LopdEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('Lopd')
            ->performedOn($event->lopd)
            ->log(':causer.name created Lopd :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('Lopd')
            ->performedOn($event->lopd)
            ->log(':causer.name updated Lopd :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('Lopd')
            ->performedOn($event->lopd)
            ->log(':causer.name deleted Lopd :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('Lopd')
            ->performedOn($event->lopd)
            ->log(':causer.name permanently deleted Lopd :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            LopdDeleted::class,
            'App\Listeners\LopdEventListener@onDeleted'
        );


        $events->listen(
            LopdDestroyed::class,
            'App\Listeners\LopdEventListener@onDestroyed'
        );

        $events->listen(
            LopdCreated::class,
            'App\Listeners\LopdEventListener@onCreated'
        );

        $events->listen(
            LopdUpdated::class,
            'App\Listeners\LopdEventListener@onUpdated'
        );
    }
}
