<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Office\OfficeDeleted;
use App\Events\Office\OfficeCreated;
use App\Events\Office\OfficeUpdated;
use App\Events\Office\OfficeDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class OfficeEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('Office')
            ->performedOn($event->Office)
            ->log(':causer.name created Office :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('Office')
            ->performedOn($event->office)
            ->log(':causer.name updated Office :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('Office')
            ->performedOn($event->Office)
            ->log(':causer.name deleted Office :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('Office')
            ->performedOn($event->Office)
            ->log(':causer.name permanently deleted Office :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            OfficeDeleted::class,
            'App\Listeners\OfficeEventListener@onDeleted'
        );


        $events->listen(
            OfficeDestroyed::class,
            'App\Listeners\OfficeEventListener@onDestroyed'
        );

        $events->listen(
            OfficeCreated::class,
            'App\Listeners\OfficeEventListener@onCreated'
        );

        $events->listen(
            OfficeUpdated::class,
            'App\Listeners\OfficeEventListener@onUpdated'
        );
    }
}
