<?php

namespace App\Listeners;

use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Queue\InteractsWithQueue;
use App\Events\Team\TeamDeleted;
use App\Events\Team\TeamCreated;
use App\Events\Team\TeamUpdated;
use App\Events\Team\TeamDestroyed;
use Illuminate\Auth\Events\PasswordReset;

class TeamEventListener
{

    /**
     * @param $event
     */
    public function onCreated($event)
    {
        activity('team')
            ->performedOn($event->team)
            ->log(':causer.name created Team :subject.name');
    }

     /**
     * @param $event
     */
    public function onUpdated($event)
    {
        activity('team')
            ->performedOn($event->team)
            ->log(':causer.name updated Team :subject.name');
    }

    /**
     * @param $event
     */
    public function onDeleted($event)
    {
        activity('team')
            ->performedOn($event->team)
            ->log(':causer.name deleted Team :subject.name');
    }

    /**
     * @param $event
     */
    public function onDestroyed($event)
    {
        activity('team')
            ->performedOn($event->team)
            ->log(':causer.name permanently deleted Team :subject.name');
    }

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Handle the event.
     *
     * @param  object  $event
     * @return void
     */
    public function handle(Login $event)
    {
        //
    }

     /**
     * Register the listeners for the subscriber.
     *
     * @param \Illuminate\Events\Dispatcher $events
     */
    public function subscribe($events)
    {
        $events->listen(
            TeamDeleted::class,
            'App\Listeners\TeamEventListener@onDeleted'
        );


        $events->listen(
            TeamDestroyed::class,
            'App\Listeners\TeamEventListener@onDestroyed'
        );

        $events->listen(
            TeamCreated::class,
            'App\Listeners\TeamEventListener@onCreated'
        );

        $events->listen(
            TeamUpdated::class,
            'App\Listeners\TeamEventListener@onUpdated'
        );
    }
}
