<?php

namespace App\Models\Traits\Method;

use Illuminate\Support\Collection;
use App\Models\Master;

/**
 * Trait UserMethod.
 */
trait UserMethod
{
    /**
     * @return bool
     */
    public function isMasterAdmin(): bool
    {
        return $this->id === 1;
    }

     /**
     * @return mixed
     */
    public function isSuperAdmin(): bool
    {
        return $this->type === self::TYPE_SUPER_ADMIN;
    }

    /**
     * @return mixed
     */
    public function isAdmin(): bool
    {
        return $this->type === self::TYPE_ADMIN || $this->type === self::TYPE_SUPER_ADMIN;
    }

    /**
     * @return mixed
     */
    public function isUser(): bool
    {
        return $this->type === self::TYPE_USER || $this->type === self::TYPE_USER_ADMIN;
    }

        /**
     * @return mixed
     */
    public function isUserAdmin(): bool
    {
        return $this->type === self::TYPE_USER_ADMIN;
    }


    /**
     * @return mixed
     */
    public function hasAllAccess(): bool
    {
        return $this->type === self::TYPE_SUPER_ADMIN || $this->type === self::TYPE_ADMIN;;
    }

    /**
     * @param $type
     *
     * @return bool
     */
    public function isType($type): bool
    {
        return $this->type === $type;
    }

    /**
     * @return mixed
     */
    public function canChangeEmail(): bool
    {
        return config('boilerplate.access.user.change_email');
    }

    /**
     * @return bool
     */
    public function isActive(): bool
    {
        return $this->active;
    }

    /**
     * @return bool
     */
    public function isVerified(): bool
    {
        return $this->email_verified_at !== null;
    }

    /**
     * @param int $size
     * @return string
     */
    public function getAvatar($size = 4): string
    {
        $value = '';
        if ($this->image_location) {
            $style = '';
            if ($size==1) {
                $style = "style='width: 25px'";
            }
            $value = "<img alt='avatar' class='img-size-50 mr-3 img-circle'".$style." src='".asset('storage/uavatar/'.$this->id.'/'.$this->image_location)."'>";
        } else {
            $value = "<i class='fas fa-user fa-".$size."x'></i>";
        }
        return $value;
    }

    /**
     * @return array|null
     */
    public function hasErrors(): ?array
    {

        $errors = [
            'status' => false,
            'message' => ''
        ];

        $company = null;
        $team = null;
        $delegation = null;
        $office = null;

        $company = $this->myCompany;
        if (!$company) {
            $errors['status'] = true;
            $errors['message'] = __('front.lead.message.no_company');
            return $errors;
        }
        $team = $this->myTeam;
        if (!$team) {
            $errors['status'] = true;
            $errors['message'] = __('front.lead.message.no_team');
            return $errors;
        }
        $office = $this->myOffice;
        if (!$office) {
            $errors['status'] = true;
            $errors['message'] = __('front.lead.message.no_office');
            return $errors;
        }
        $delegation = $this->myDelegation;
        if (!$delegation) {
            $errors['status'] = true;
            $errors['message'] = __('front.lead.message.no_delegation');
            return $errors;
        }
        return null;
    }


    /**
     * @return null[]
     */
    public function getDelegates(): array
    {

        $masters = Master::where('user_id', $this->id)->get();

        $data = [
            'companies' => null,
            'delegations' => null,
            'offices' => null,
            'teams' => null
        ];


        foreach($masters as $master) {
            //Obtener las empresas
            $companies = $master->companies;
            foreach ($companies as $company) {
                $data['companies'][] = $company->id;
            }

             //Obtener las delegaciones
             $delegations = $master->delegations;
             foreach ($delegations as $delegation) {
                 $data['delegations'][] = $delegation->id;
             }

             //Obtener las oficinas
             $offices = $master->offices;
             foreach ($offices as $office) {
                 $data['offices'][] = $office->id;
             }

             //Obtener los equipos
             $teams = $master->teams;
             foreach ($teams as $team) {
                 $data['teams'][] = $team->id;
             }
        }

        return $data;
    }
}
