<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use App\Models\Traits\Relationship\UserRelationship;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use App\Models\Traits\Method\UserMethod;
use Lab404\Impersonate\Models\Impersonate;
use Illuminate\Database\Eloquent\SoftDeletes;
use Laravel\Fortify\TwoFactorAuthenticatable;

class User extends Authenticatable implements MustVerifyEmail
{
    use HasFactory, Notifiable, Impersonate, SoftDeletes, TwoFactorAuthenticatable, UserRelationship, UserMethod;

    public const TYPE_ADMIN = 'admin';
    public const TYPE_SUPER_ADMIN = 'superadmin';
    public const TYPE_USER_ADMIN = 'useradmin';
    public const TYPE_USER = 'user';


    public const CONTRACT_MERCANTIL = 'autonomo';
    public const CONTRACT_LABORAL_DIRECTO = 'directo';
    public const CONTRACT_REPRESENTANTE_COMERCIO = 'representante';
    public const CONTRACT_LABORAL = 'laboral';

    public const AVATAR_FOLDER = 'uavatar';

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'users';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'type',
        'name',
        'username',
        'email',
        'password',
        'name',
        'last_name',
        'last_name_2',
        'email_verified_at',
        'password',
        'password_changed_at',
        'active',
        'timezone',
        'last_login_at',
        'last_login_ip',
        'to_be_logged_out',
        'company_id',
        'team_id',
        'delegation_id',
        'office_id'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

     /**
     * Return true or false if the user can impersonate an other user.
     *
     * @param void
     * @return  bool
     */
    public function canImpersonate(): bool
    {
        return 1;
    }

    /**
     * Return true or false if the user can be impersonate.
     *
     * @param void
     * @return  bool
     */
    public function canBeImpersonated(): bool
    {
        return 1;
    }

    public function roles(){
        return $this->belongsToMany('App\Models\Role')->withTimestamps();
    }

    public function notifications(){
        return $this->belongsToMany('App\Models\Notification')->withTimestamps();
    }

    public function myCompany(){
        return $this->belongsTo('App\Models\Company', 'company_id');
    }

    public function myDelegation(){
        return $this->belongsTo('App\Models\Delegation', 'delegation_id');
    }

    public function myOffice(){
        return $this->belongsTo('App\Models\Office', 'office_id');
    }

    public function myTeam(){
        return $this->belongsTo('App\Models\Team', 'team_id');
    }

    public function companies()
    {
        return $this->belongsToMany('App\Models\Company', 'company_user')->withTimestamps();
    }

    public function messages()
    {
        return $this->belongsToMany('App\Models\Message', 'user_message');
    }

    public function address()
    {
        return $this->morphOne(Address::class, 'addressable');
    }
}
