<?php

namespace App\Services;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Interfaces\StatusInterface;
use App\Http\Requests\Backend\CampaignRequest;
use App\Models\Campaign;
use Illuminate\Validation\ValidationException;
use App\Exceptions\GeneralException;
use Exception;
use App\Events\Campaign\CampaignUpdated;
use App\Events\Campaign\CampaignCreated;
use App\Events\Campaign\CampaignDeleted;
use App\Events\Campaign\CampaignDestroyed;
use App\Models\Company;
use Throwable;

/**
 * Class CampaignService.
 */
class CampaignService implements StatusInterface
{
    /**
     * @param CampaignRequest $request
     * @return mixed
     */
    public function change(CampaignRequest $request) {
        $users = null;
        $data = $request->all();

        $id = isset($data['id']) ? $data['id'] : null;
        $checked = isset($data['checked']) ? $data['checked'] : null;
        if ($id) {
            $request->session()->forget('campaign');
            if ($checked != "false") {
                $request->session()->put('campaign', $id);
            }
            return [self::SUCCESS => self::SUCCESS];
        } else {
            return [self::ERROR => self::ERROR];
        }
    }


    /* @param Campaign $campaign
     *
     * @return bool
     */
    public function delete(Campaign $campaign): bool
    {
        try {
            DB::beginTransaction();

            $campaign->delete();
            $campaign->save();
            //Logs
            Log::info('Borrada campaign '.$campaign->id);
            event(new CampaignDeleted($campaign));
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

        /**
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function deleteImage(Campaign $campaign): bool
    {
        try {
            DB::beginTransaction();
            $campaign->image_location=NULL;
            $campaign->Save();
            //Logs
            Log::info('Borrada la imagen '.$campaign->id);
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

    /**
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function destroy(Campaign $campaign): bool
    {
        try {
            DB::beginTransaction();
            $this->delete($campaign);
            $campaign->forceDelete();
            //Logs
            Log::info('Destruida campaign '.$campaign->id);
            event(new CampaignDestroyed($campaign));
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

             /**
     * @param  CampaignRequest $request
     *
     * @return Campaign
     * @throws GeneralException
     * @throws Throwable
     */
    public function updateCampaign(CampaignRequest $request): ?Campaign
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            //Buscar el equipo
            $campaign = null;
            $campaignId = isset($data['campaign-id']) ? $data['campaign-id'] : null;
            if ($campaignId) {
                $campaign = Campaign::where('id', $campaignId)->first();
                if ($campaign) {
                    $campaign = $this->manageCampaign($request, $campaign, $data);
                }
            }
            if (!$campaign) {
                throw new GeneralException(__('auth.general_error'));
            }
            //Logs
            Log::info('Actualizada campaign '.$campaign->id);
            event(new CampaignUpdated($campaign));
            DB::commit();
            return $campaign;
        } catch (ValidationException $e) {
            throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }


     /**
     * @param  CampaignRequest $request
     *
     * @return Campaign
     * @throws GeneralException
     * @throws Throwable
     */
    public function createCampaign(CampaignRequest $request): ?Campaign
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            $campaign = new Campaign();
            $campaign = $this->manageCampaign($request, $campaign, $data);
            //Logs
            Log::info('Creada la campaign '.$campaign->id);
            event(new CampaignCreated($campaign));
            DB::commit();
            return $campaign;
            //return false;
        } catch (ValidationException $e) {
                throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }



    /**
     * @param CampaignRequest $request
     * @param Campaign $campaign
     *
     * @param $data
     * @return Campaign
     * @throws ValidationException
     */
    private function manageCampaign($request, $campaign, $data): Campaign
    {

        $campaign->name = isset($data['name']) ? $data['name'] : null;
        $campaign->slug = isset($data['name']) ? str_slug($data['name'], "-") : null;
        $campaign->company_id = isset($data['company']) ? $data['company'] : null;
        $campaign->active = isset($data['active']) ? $data['active'] : false;

        $campaign->Save();
        $campaignId = $campaign->id;
        //Insertar avatar
        if ($request->hasFile('avatar')) {
            $file = $request->file('avatar');
            $filename = HelperService::uploadFile($file, 'caavatar', $campaignId);
            $campaign->image_location = $filename;
        }
        $campaign->Save();
        return $campaign;
    }

}
