<?php

namespace App\Services;

use Illuminate\Support\Facades\DB;
use App\Models\CompanyLink;
use Illuminate\Support\Facades\Log;
use Exception;

/**
 * Class CompanyLinkService.
 */
class CompanyLinkService
{

    /**
     * @param CompanyLink $companyLink
     * @return boolean
     */
    public function delete(CompanyLink $companyLink): bool
    {
        try {
            DB::beginTransaction();
            //Borrar el link
            $companyLink->delete();
            $companyLink->Save();
            //Logs
            Log::info('Borrado el link'.$companyLink->id);
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

     /**
     * @param CompanyLink  $companyLink
     *
     * @return boolean
     */
    public function destroy(CompanyLink $companyLink): bool
    {
        try {
            DB::beginTransaction();
            $this->delete($companyLink);

            $companyLink->forceDelete();
            //Logs
            Log::info('Destruida el link '.$companyLink->id);
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

    /**
     * @param  CompanyLink  $companyLink
     * @param array $data
     * @return boolean
     */
    public function update(CompanyLink $companyLink, array $data) : bool
    {
        try {
            DB::beginTransaction();
            $companyLink->name = isset($data['company-link-name']) ? $data['company-link-name'] : '';
            $companyLink->url = isset($data['company-link-url']) ? $data['company-link-url'] : '';
            $companyLink->active = isset($data['company-link-active']) ? $data['company-link-active'] : 0;
            $companyLink->Save();
            //Logs
            Log::info('Actaulizado el link '.$companyLink->name);
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }


    /**
     * @param array $data
     * @return boolean
     */
    public function create(array $data) : bool
    {
        try {
            $companyLink = new CompanyLink();
            if (isset($data['company-id'])) {
                $companyLink->company_id = $data['company-id'];
                if ($this->update($companyLink, $data)) {
                    //Logs
                    Log::info('Creado el link '.$companyLink->name);
                    return true;
                }
            }
        } catch (Exception $e) {
            Log::error($e);
        }
        return false;
    }
}
