<?php

namespace App\Services;

use App\Models\Team;
use App\Models\Company;
use App\Models\Delegation;
use App\Models\Office;
use App\Models\User;
use App\Models\Address;
use App\Models\Campaign;
use App\Models\Province;
use Illuminate\Support\Facades\Storage;
use Illuminate\Validation\ValidationException;
use Image;
use NifValidator\NifValidator;

/**
 * Class HelperService.
 */
class HelperService
{
    /**
     * @param $file
     * @param $type
     * @param $id
     * @return string|null
     */
    public static function uploadFile($file, $type, $id) {
        // Handle uploads
        $filename = null;

        if ($id) {
            switch ($type) {
                case 'cavatar': case 'uavatar': case 'tavatar':  case 'davatar':  case 'oavatar': case 'caavatar':
                    $newExtension = 'jpg';

                    $extension = $file->getClientOriginalExtension();
                    $name = $file->getClientOriginalName();
                    $file = Image::make($file->getRealPath())->resize(300, 300, function ($constraint) {
                        $constraint->aspectRatio();
                    });
                    $file->encode($newExtension);
                    $filename = md5($name).'.'.$newExtension;
                    break;
                default:
                    $extension = $file->getClientOriginalExtension();
                    $filename = md5(time()).'.'.$extension;
                    break;
            }
        }
        if ($filename) {
            $folder = User::AVATAR_FOLDER;
            if ($type == 'cavatar') {
                $folder = Company::AVATAR_FOLDER;
            } elseif ($type == 'tavatar') {
                $folder = Team::AVATAR_FOLDER;
            } elseif ($type == 'davatar') {
                $folder = DELEGATION::AVATAR_FOLDER;
            } elseif ($type == 'oavatar') {
                $folder = OFFICE::AVATAR_FOLDER;
            } elseif ($type == 'uavatar') {
                $folder = USER::AVATAR_FOLDER;
            } elseif ($type == 'caavatar') {
                $folder = CAMPAIGN::AVATAR_FOLDER;
            } else {
                return null;
            }
            $path = DIRECTORY_SEPARATOR.$folder.DIRECTORY_SEPARATOR.$id;
            Storage::disk('public')->put($path.DIRECTORY_SEPARATOR.$filename, $file);
        }
        return $filename;
    }

    /**
     * @param $data
     * @param bool $text
     * @return string
     */
    public static function getIcon($data, $text = true): string
    {
        if ($data) {
            if ($text) {
                $icon = '<span class="badge badge-success" data-toggle="tooltip" title="' . trans('backend.icon.yes') . '" data-original-title="' . $data . '">' . $data . '</span>';
            } else {
                $icon = '<span class="badge badge-pill badge-success" data-toggle="tooltip" title="'.trans('backend.icon.yes').'" data-original-title="'.trans('backend.icon.yes').'">'.trans('backend.icon.yes').'</span>';
            }
        } else {
            $icon = '<span class="badge badge-danger" data-toggle="tooltip" title="'.trans('backend.icon.no').'" data-original-title="'.trans('backend.icon.no').'">'.trans('backend.icon.no').'</span>';
        }
        return $icon;
    }

    /**
     * @param $nif
     * @return bool
     * @throws ValidationException
     */
    public static function validateNif($nif): bool
    {
        $result = true;
        //Validar el cif
        if(NifValidator::isValid($nif) == false) {
            throw ValidationException::withMessages(['nif' => __('Nif')]);
            return false;
        }
        return $result;
    }

    /**
     * @param $iban
     * @return bool
     * @throws ValidationException
     */
    public static function validateAccount($iban): bool
    {
        $cuenta = strtoupper($iban);
        //Validar la cuenta
        if(!verify_iban($cuenta,$machine_format_only=false)) {
            throw ValidationException::withMessages(['account' =>  __('backend.company.form.account')]);
            return false;
        }
        return true;
    }

    /**
     * @param $active
     * @return string
     */
    public static function getYesNoIconTable($active): string
    {
        $icon = '';
        if ($active) {
            $icon = '<span class="badge badge-success" data-toggle="tooltip" title="'.trans('backend.icon.yes').'" data-original-title="'.trans('backend.icon.yes').'">'.trans('backend.icon.yes').'</span>';
        } else {
            $icon = '<span class="badge badge-danger" data-toggle="tooltip" title="'.trans('backend.icon.no').'" data-original-title="'.trans('backend.icon.no').'">'.trans('backend.icon.no').'</span>';
        }
        return $icon;
    }

    /**
     * @param $entity
     * @param $data
     * @return mixed
     */
    public static function updateAddress($entity, $data) {
        //Address
        $address = $entity->address;
        if (!$address) {
            $address = new Address();
        }
        $address->via_id = isset($data['via']) ? $data['via'] : null;
        $address->name_via = isset($data['namevia']) ? $data['namevia'] : null;
        $address->num_via = isset($data['numvia']) ? $data['numvia'] : null;
        $address->floor = isset($data['floor']) ? $data['floor'] : null;
        $address->door = isset($data['door']) ? $data['door'] : null;
        $address->letter = isset($data['letter']) ? $data['letter'] : null;
        $address->address_more = isset($data['address_more']) ? $data['address_more'] : null;

        $address->postcode = isset($data['postcode']) ? $data['postcode'] : null;
        $address->city = isset($data['city']) ? $data['city'] : null;
        $address->country_id = isset($data['country']) ? $data['country'] : null;

        if (isset($data['province_id'])) {
            $address->province_id = $data['province_id'];
            //Buscar la provincia
            $province = Province::where('id', $data['province_id'])->first();
            if ($province) {
                $address->province = $province->name;
            }
        } else {
            $address->province = isset($data['province']) ? $data['province'] : "";
        }
        $entity->address()->save($address);

        return $entity;
    }
}
