<?php

namespace App\Services;

use Illuminate\Contracts\Validation\Validator;
use Illuminate\Support\Facades\DB;
use App\Events\Lead\LeadUpdated;
use App\Events\Lead\LeadCreated;
use App\Events\Lead\LeadDeleted;
use App\Events\Lead\LeadDestroyed;
use App\Models\Lead;
use App\Models\User;
use App\Models\Client;
use App\Models\LeadLine;
use App\Models\Campaign;
use App\Models\Variant;
use Illuminate\Support\Facades\Log;
use Illuminate\Http\Request;
use App\Http\Requests\Front\LeadRequest;
use App\Exceptions\GeneralException;
use Illuminate\Validation\ValidationException;
use Exception;
use Throwable;
use App\Services\HelperService;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;

/**
 * Class LeadService.
 */
class LeadService
{
    /**
     * @param Lead $lead
     *
     * @return bool
     */
    public function delete(Lead $lead): bool
    {
        try {
            DB::beginTransaction();

            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }



    /**
     * @param Lead $lead
     *
     * @return bool
     */
    public function destroy(Lead $lead): bool
    {
        try {
            DB::beginTransaction();
            $this->delete($lead);


            $lead->forceDelete();

            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }


     /**
     * @param  LeadRequest $request
     *
     * @return Lead
     * @throws GeneralException
     * @throws Throwable
     */
    public function createLead(LeadRequest $request): ?Lead
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            $lead = new Lead();
            $lead = $this->manageLead($request, $lead, $data);
            //Logs
            Log::info('Creado el Lead '.$lead->id);
            //throw new GeneralException(__('auth.general_error'));
            event(new LeadCreated($lead));
            DB::commit();
            return $lead;
            //return false;
        } catch (ValidationException $e) {
            throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
            throw new GeneralException(__('auth.general_error'));
        }
        return null;
    }


         /**
     * @param  LeadRequest $request
     *
     * @return Lead
     * @throws GeneralException
     * @throws Throwable
     */
    public function updateLead(LeadRequest $request): ?Lead
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            $lead = null;
            $LeadId = isset($data['lead-id']) ? $data['lead-id'] : null;
            if ($LeadId) {
                $lead = Lead::where('id', $LeadId)->first();
                if ($lead) {
                    $lead = $this->manageLead($request, $lead, $data);
                }
            }
            //Logs
            Log::info('Actualizado el Lead '.$lead->id);
            //throw new GeneralException(__('auth.general_error'));
            event(new LeadUpdated($lead));
            DB::commit();
            return $lead;
            //return false;
        } catch (ValidationException $e) {
            throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
            throw new GeneralException($e->getMessage());
        }
        return null;
    }


    /**
     * @param $request
     * @param $lead
     * @param $data
     * @return mixed
     */
    private function manageLead($request, $lead, $data) {

        //Buscar si existe el cliente
        $nif = isset($data['nif']) ? $data['nif'] : null;
        $client = Client::where('nif', $nif)->first();
        if (!$client) {
            $client = new Client();
        }
        $client->code = isset($data['code']) ? $data['code'] : null;
        $client->name = isset($data['name']) ? $data['name'] : null;
        $client->last_name = isset($data['last_name']) ? $data['last_name'

        ] : null;
        $client->last_name_2 = isset($data['last_name_2']) ? $data['last_name_2'] : null;
        $client->email = isset($data['email']) ? $data['email'] : null;
        $client->phone = isset($data['phone']) ? $data['phone'] : null;
        $client->mobile = isset($data['mobile']) ? $data['mobile'] : null;
        $iban = isset($data['iban']) ? $data['iban'] : null;
        $account = isset($data['account']) ? $data['account'] : null;
        $variantId = isset($data['variant']) ? $data['variant'] : null;
        $periodicityId  = isset($data['periodicity']) ? $data['periodicity'] : null;

        if (!$periodicityId) {
            throw new GeneralException(__('front.lead.message.no_periodicity'));
        }

        $lead->identificator = $lead->generateBarcodeNumber();
        $lead->signature_date = Carbon::now('Europe/Madrid')->toDateTimeString();
        $userId = isset($data['user-id']) ? $data['user-id'] : null;
        $user = User::where('id', $userId)->first();
        if (!$user) {
            throw new GeneralException(__('front.lead.message.no_user'));
        }

        $lead->user_id = $user->id;
        $lead->team_id = $user->team_id;
        $lead->company_id = $user->company_id;
        $lead->office_id = $user->office_id;
        $lead->delegation_id = $user->delegation_id;
        $status = isset($data['status']) ? $data['status'] : null;
        if ($status == LEAD::REGISTER_TYPE_OK || $status == LEAD::REGISTER_TYPE_KO) {
            $lead->closed = 1;
            $lead->status = $status;
        }

        $lead->save();


        if (!HelperService::validateNif($nif)) {
            throw new GeneralException(__('auth.general_error'));
        }

        $client->nif = $nif;

        $cuenta = strtoupper($iban.$account);
        if (!HelperService::validateAccount($cuenta)) {
            throw new GeneralException(__('auth.general_error'));
        }
        $client->account = $cuenta;
        $client->save();
        //Actualizar el address
        $client = HelperService::updateAddress($client, $data);

        $client->myLeads()->save($lead);

        //Obtener la campana
        $campaignId = isset($data['campaign-id']) ? $data['campaign-id'] : null;
        $campaign = Campaign::where('id', $campaignId)->first();
        if (!$campaign) {
            throw new GeneralException(__('front.lead.message.no_campaign'));
        }

        //Obtener la variante
        $variant = Variant::where('id', $variantId)->first();
        if (!$variant) {
            throw new GeneralException(__('front.lead.message.no_product'));
        }
        //Crear las linea de pedido

        $leadLineId = $lead->myLeadLines()->first();
        $leadLine = LeadLine::where('id', $leadLineId)->first();
        if (!$leadLine) {
            $leadLine = new LeadLine();
        }
        $leadLine->variant_id = $variant->id;
        $leadLine->campaign_id = $campaignId;
        $leadLine->periodicity_id = $periodicityId;
        $lead->myLeadLines()->save($leadLine);
        $leadLine->save();

        return $lead;
    }


    /**
     * @param Request $request
     * @return null
     */
    public function searchDelegate(Request $request)
    {

        $leads = null;

        $data = $this->getDataLeads($request);

        $userId = Auth::User()->id;

        $delegates = Auth::User()->getDelegates();

        $companies = $delegates['companies'];
        $delegations = $delegates['delegations'];
        $offices = $delegates['offices'];
        $teams = $delegates['teams'];


        if ($data) {

            $leads = Lead::where([['signature_date', '>=', $data['start']], ['signature_date', '<=',  $data['finish']]]);
            if ($companies){
                $leads = $leads->whereIn('company_id', $companies);
            }
            if ($delegations){
                $leads = $leads->whereIn('delagation_id', $delegations);
            }

            if ($offices){
                $leads = $leads->whereIn('office_id', $offices);
            }

            if ($teams){
                $leads = $leads->whereIn('team_id', $teams);
            }
            $leads = $leads->paginate(10);
        }

        return $leads;
    }

    /**
     * @param Request $request
     * @return null
     */
    public function searchRegister(Request $request)
    {

        $leads = null;

        $userId = Auth::User()->id;

        $data = $this->getDataLeads($request);
        if ($data) {
            $leads = Lead::where([['user_id', $userId ],['signature_date', '>=', $data['start']], ['signature_date', '<=',  $data['finish']]])->paginate(10);

        }

        return $leads;

    }

    /**
     * @param Request $request
     * @return array|null
     */
    private function getDataLeads(Request $request): ?array
    {

        $formData = $request->all();

        $leads = null;

        $start = isset($formData['start']) ? $formData['start'] : null;
        $finish = isset($formData['finish']) ? $formData['finish'] : null;


        $start = Carbon::createFromFormat('d/m/Y H:i', $start);
        $finish = Carbon::createFromFormat('d/m/Y H:i', $finish);

        if (!$start || !$finish) {
            return null;
        } else if (Carbon::parse($start)->gte(Carbon::parse($finish))) {
            return null;
        } else {
            $newStart = Carbon::parse($start)->format('Y-m-d H:i:s');
            $newFinish = Carbon::parse($finish)->format('Y-m-d H:i:s');
        }


        return [
            'start' => $newStart ,
            'finish' => $newFinish
        ];
    }
}
