<?php

namespace App\Services;

use Illuminate\Contracts\Validation\Validator;
use Illuminate\Support\Facades\DB;
use App\Models\Lopd;
use Illuminate\Support\Facades\Log;
use App\Http\Requests\Backend\LopdRequest;
use Illuminate\Support\Facades\Storage;
use Illuminate\Validation\ValidationException;
use App\Events\Lopd\LopdCreated;
use App\Events\Lopd\LopdUpdated;
use App\Events\Lopd\LopdDeleted;
use App\Events\Lopd\LopdDestroyed;
use App\Exceptions\GeneralException;
use Exception;
use Throwable;

/**
 * Class LopdService.
 */
class LopdService
{
    /**
     * @param lopd $lopd
     *
     * @return bool
     */
    public function delete(Lopd $lopd): bool
    {
        try {
            DB::beginTransaction();
            $lopd->delete();
            $lopd->Save();
            //Logs
            Log::info('Borrada la lopd '.$lopd->id);
            event(new LopdDeleted($lopd));
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

    /**
     * @param lopd $lopd
     *
     * @return bool
     */
    public function destroy(lopd $lopd): bool
    {
        try {
            DB::beginTransaction();
            $this->delete($lopd);
            $lopd->forceDelete();
            //Logs
            Log::info('Destruida la lopd '.$lopd->id);
            event(new LopdDestroyed($lopd));
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

         /**
     * @param  lopdRequest $request
     *
     * @return lopd
     * @throws GeneralException
     * @throws Throwable
     */
    public function updateLopd(lopdRequest $request): ?lopd
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            //Buscar la lopd
            $lopd = null;
            $lopdId = isset($data['lopd-id']) ? $data['lopd-id'] : null;
            if ($lopdId) {
                $lopd = lopd::where('id', $lopdId)->first();
                if ($lopd) {
                    //Pasar las lopd a inactivas
                    Lopd::where([['id', '<>',$data['lopd-id']], ['type', $lopd->type]])->update(array('active' => 0));
                    $lopd = $this->manageLopd($request, $lopd, $data);
                }
            }
            //Logs
            Log::info('Actualizada la lopd '.$lopd->id);
            event(new LopdUpdated($lopd));
            DB::commit();
            return $lopd;
        } catch (ValidationException $e) {
            throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }



     /**
     * @param  lopdRequest $request
     *
     * @return lopd
     * @throws GeneralException
     * @throws Throwable
     */
    public function createLopd(lopdRequest $request): ?lopd
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            $lopd = new Lopd();
            $type = isset($data['type']) ? $data['type'] : null;
            Lopd::query()->where('type', $type )->update(array('active' => 0));
            $lopd = $this->manageLopd($request, $lopd, $data);
            //Logs
            Log::info('Creada la lopd '.$lopd->id);
            event(new LopdCreated($lopd));
            DB::commit();
            return $lopd;
            //return false;
        } catch (ValidationException $e) {
                throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }

    /**
     * @param lopdRequest $request
     * @param lopd $lopd
     *
     * @param $data
     * @return lopd
     * @throws ValidationException
     */
    private function manageLopd($request, $lopd, $data) {
        $lopd->name = isset($data['name']) ? $data['name'] : null;
        $lopd->type = isset($data['type']) ? $data['type'] : null;
        $lopd->text = isset($data['text']) ? $data['text'] : null;
        $lopd->active = isset($data['active']) ? $data['active'] : false;
        $lopd->Save();
        return $lopd;
    }
}
