<?php

namespace App\Services;

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Validation\ValidationException;
use App\Http\Requests\Backend\MasterRequest;
use App\Exceptions\GeneralException;
use Illuminate\Support\Facades\Auth;
use App\Models\Company;
use App\Models\Delegation;
use App\Models\Office;
use App\Models\Team;
use App\Models\User;
use App\Models\Master;
use Exception;
use Throwable;
use App\Http\Controllers\Interfaces\StatusInterface;

/**
 * Class MasterService.
 */
class MasterService implements StatusInterface
{

    /**
     * @param MasterRequest $request
     *
     * @return array|null
     * @throws Exception
     * @throws Throwable
     */
    public function getEntity(MasterRequest $request): ?array
    {
        try {
            DB::beginTransaction();
            $formData = $request->all();
            $data = array();
            $tipo = isset($formData['type']) ? $formData['type'] : null;
            $status = isset($formData['status']) ? $formData['status'] : null;
            $tipoName = '';
            if (!$tipo) {
                return [self::ERROR => __('backend.master.error.type')];
            }
            if ($status == 0) {
                switch ($tipo) {
                    case 'company':
                        $data = $this->getCompanies();
                        $tipoName = __('backend.master.entity.company');
                        break;
                    case 'team':
                        $data = $this->getTeams();
                        $tipoName = __('backend.master.entity.team');
                        break;
                    case 'delegation':
                        $data = $this->getDelegations();
                        $tipoName = __('backend.master.entity.delegation');
                        break;
                    case 'office':
                        $data = $this->getOffices();
                        $tipoName = __('backend.master.entity.office');
                        break;
                    case 'user':
                        $data = $this->Users();
                        $tipoName = __('backend.master.entity.user');
                        break;
                    default:
                        return [self::ERROR => __('backend.master.error.type')];
                        break;
                }
                DB::commit();
                return [self::SUCCESS => __('backend.master.success.success'), 'data' => $data, 'text' => __('backend.master.actions.delegate', ['entity' => $tipoName])];
            } elseif ($status == 1) {
                //Buscar los usuarios
                $selection = isset($formData['selection']) ? $formData['selection'] : null;
                if (!$selection) {
                    return [self::ERROR => __('backend.master.error.selection', ['entity' => $tipoName])];
                }
                switch ($tipo) {
                    case 'company':
                        $data = $this->getUsersCompany($selection);
                        break;
                    case 'team':
                        $data = $this->getUsersTeam($selection);
                        break;
                    case 'delegation':
                        $data = $this->getUsersDelegation($selection);
                        break;
                    case 'office':
                        $data = $this->getUsersOffice($selection);
                        break;
                    case 'user':
                        $data = $this->getUsers($selection);
                        break;
                    default:
                        return [self::ERROR => __('backend.master.error.type')];
                        break;
                }
                DB::commit();
                return [self::SUCCESS => __('backend.master.success.success'), 'success' => self::SUCCESS, 'data' => $data];
            }
        } catch (ValidationException $e) {
            DB::rollBack();
            throw new ValidationException($e->getMessage());
        } catch (Exception $e) {
            Log::error($e);
            throw new Exception(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }

    /**
     * @param MasterRequest $request
     *
     * @return array|null
     * @throws Exception
     * @throws Throwable
     */
    public function saveEntity(MasterRequest $request): ?array
    {
        try {
            DB::beginTransaction();

            $formData = $request->all();
            $tipo = isset($formData['type']) ? $formData['type'] : null;
            $status = isset($formData['status']) ? $formData['status'] : null;
            $selection = isset($formData['selection']) ? $formData['selection'] : null;
            $list = isset($formData['list']) ? $formData['list'] : null;
            $tipoName = '';
            if (!$tipo) {
                return [self::ERROR => __('backend.master.error.type')];
            }
            if (!$selection) {
                return [self::ERROR => __('backend.master.error.selection', ['entity' => $tipo])];
            }
            if ($status != 1) {
                return [self::ERROR => __('backend.master.error.status')];
            } elseif ($status == 1) {
                //Insertar elementos
                switch ($tipo) {
                    case 'company':
                        $data = $this->addUsersCompany($list, $selection);
                        DB::commit();
                        //Obtener elementos
                        $data = $this->getUsersCompany($selection);
                        $tipoName = __('backend.master.entity.company');
                        break;
                    case 'team':
                        $data = $this->addUsersTeam($list, $selection);
                        DB::commit();
                        //Obtener elementos
                        $data = $this->getUsersTeam($selection);
                        $tipoName = __('backend.master.entity.team');
                        break;
                    case 'delegation':
                        $data = $this->addUsersDelegation($list, $selection);
                        DB::commit();
                        //Obtener elementos
                        $data = $this->getUsersDelegation($selection);
                        $tipoName = __('backend.master.entity.delegation');
                        break;
                    case 'office':
                        $data = $this->addUsersOffice($list, $selection);
                        DB::commit();
                        //Obtener elementos
                        $data = $this->getUsersOffice($selection);
                        $tipoName = __('backend.master.entity.office');
                        break;
                    case 'user':
                        $data = $this->addUsers($list, $selection);
                        DB::commit();
                        //Obtener elementos
                        $data = $this->getUsers($selection);
                        $tipoName = __('backend.master.entity.office');
                        break;
                    default:
                        return [self::ERROR => __('backend.master.error.type')];
                        break;
                }
                Log::info('Delegado el control en ' . $tipoName . ' con ' . json_encode($data));
                DB::commit();
                return [self::SUCCESS => __('backend.master.success.success'), 'finish' => true, 'text' => __('backend.master.actions.delegate', ['entity' => $tipoName])];
            }
        } catch (ValidationException $e) {
            DB::rollBack();
            throw new ValidationException($e->getMessage());
        } catch (Exception $e) {
            Log::error($e);
            throw new Exception(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }

    /**
     * @return array
     */
    private function getCompanies()
    {
        $companies = null;
        //Si es admin se obtienen todas las companies
        if (Auth::user()->isAdmin()) {
            $companies = Company::all();
        }

        $htmlCompanies = [];
        if ($companies) {
            foreach ($companies as $company) {
                $htmlCompanies[] = ['value' => $company->id, 'text' => $company->name];
            }
        }
        return $htmlCompanies;
    }

    /**
     * @return array
     */
    private function getTeams()
    {
        $teams = null;
        //Si es admin se obtienen todas las companies
        if (Auth::user()->isAdmin()) {
            $teams = Team::all();
        } else {

        }

        $htmlTeams = [];
        if ($teams) {
            foreach ($teams as $team) {
                $htmlTeams[] = ['value' => $team->id, 'text' => $team->name];
            }
        }
        return $htmlTeams;
    }


    /**
     * @return array
     */
    private function getDelegations()
    {
        $delegations = null;
        //Si es admin se obtienen todas las companies
        if (Auth::user()->isAdmin()) {
            $delegations = Delegation::all();
        } else {

        }

        $htmlDelegations = [];
        if ($delegations) {
            foreach ($delegations as $delegation) {
                $htmlDelegations[] = ['value' => $delegation->id, 'text' => $delegation->name];
            }
        }
        return $htmlDelegations;
    }

        /**
     * @return array
     */
    private function getOffices()
    {
        $offices = null;
        //Si es admin se obtienen todas las companies
        if (Auth::user()->isAdmin()) {
            $offices = Office::all();
        } else {

        }

        $htmlOffices = [];
        if ($offices) {
            foreach ($offices as $office) {
                $htmlOffices[] = ['value' => $office->id, 'text' => $office->name];
            }
        }
        return $htmlOffices;
    }



    /**
     * @param $selection
     * @return array
     */
    private function getUsersCompany($selection)
    {

        $users = null;
        //Si es admin se obtienen todos los users. Si no lo es no se obtiene nada
        if (Auth::user()->isAdmin()) {
            $users = User::where('active', 1)->get();
        }

        $htmlUsers = [];
        if ($users) {
            foreach ($users as $user) {
                $company = Company::where('id', $selection)->first();
                $htmlUsers[] = $this->getHtmlEntity($company->masters(), $user);
            }
        }
        return $htmlUsers;
    }

    /**
     * @param $list
     * @param $selection
     * @return string
     * @throws GeneralException
     */
    private function addUsersCompany($list, $selection)
    {
        $company = Company::where('id', $selection)->first();
        return $this->saveUsersEntity($company, $list);
    }


    /**
     * @param $entity
     * @param $list
     * @throws GeneralException
     */
    private function saveUsersEntity($entity, $list)
    {
        $entity->masters()->delete();
        $entity->masters()->detach();
        if (!empty($list)) {
            foreach ($list as $userId) {
                $user = User::where('id', $userId)->first();
                if ($user && $entity) {
                    $entity->masters()->where(['user_id' => $userId])->delete();
                    $entity->masters()->create(['user_id' => $userId]);
                    $entity->Save();
                } else {
                    throw new GeneralException(__('backend.master.error.type'));
                }
            }
        }
    }

    /**
     * @param $user
     * @return mixed
     */
    private function getUsersEntityAsigned($user, $entityClass)
    {
        $userId = $user->id;

        $entities = $entityClass::all();
        foreach ($entities as $entity) {
            $result = $entity->masters()->where('user_id', $userId)->get();
        }

        /*$teams = Team::whereHas('masters', function($q) use ($userId)
        {
            $q->where('user_id', $userId);
        })->get();*/
        return $result;
    }

    /**
     * @param $entityMaster
     * @param $user
     * @return mixed
     */
    private function getHtmlEntity($entityMaster, $user)
    {
        $userId = $user->id;
        $selected = '';
        foreach ($entityMaster->get() as $master) {
            if ($master->user_id == $userId) {
                $selected = 'selected';
            }
        }
        $html = ['value' => $userId,
            'text' => $userId . ' ' . htmlentities($user->username . ' ' . $user->name . ' ' . $user->last_name . ' ' . $user->last_name_2),
            'selected' => $selected];
        return $html;
    }


    /**
     * @param $selection
     * @return array
     */
    private function getUsersTeam($selection)
    {

        $users = null;
        $htmlTeams = [];
        //Si es admin se obtienen todos los users
        if (Auth::user()->isAdmin()) {
            $users = User::where('active', 1)->get();
            if ($users) {
                foreach ($users as $user) {
                    $userId = $user->id;
                    $team = Team::where('id', $selection)->first();
                    $htmlTeams[] = $this->getHtmlEntity($team->masters(), $user);
                }
            }
        } else {
            //Buscar los usuarios asignados al equipo
            $user = Auth::user();
            $teams = $this->getUsersEntityAsigned($user, Team::class);
            foreach ($teams as $team) {
                $htmlTeams[] = $this->getHtmlEntity($team, $user);
            }
        }
        return $htmlTeams;
    }


    /**
     * @param $list
     * @param $selection
     * @return string
     * @throws GeneralException
     */
    private function addUsersTeam($list, $selection)
    {
        $team = Team::where('id', $selection)->first();
        return $this->saveUsersEntity($team, $list);
    }

    /**
     * @param $selection
     * @return array
     */
    private function getUsersDelegation($selection)
    {

        $users = null;
        $htmlDelegations = [];
        //Si es admin se obtienen todos los users
        if (Auth::user()->isAdmin()) {
            $users = User::where('active', 1)->get();
            if ($users) {
                foreach ($users as $user) {
                    $userId = $user->id;
                    $delegation = Delegation::where('id', $selection)->first();
                    $htmlDelegations[] = $this->getHtmlEntity($delegation->masters(), $user);
                }
            }
        } else {
            //Buscar los usuarios asignados al equipo
            $user = Auth::user();
            $delegations = $this->getUsersEntityAsigned($user, Delegation::class);
            foreach ($delegations as $delegation) {
                $htmlDelegations[] = $this->getHtmlEntity($delegation, $user);
            }
        }
        return $htmlDelegations;
    }


    /**
     * @param $list
     * @param $selection
     * @return string
     * @throws GeneralException
     */
    private function addUsersDelegation($list, $selection)
    {
        $delegation = Delegation::where('id', $selection)->first();
        return $this->saveUsersEntity($delegation, $list);
    }

    /**
     * @param $selection
     * @return array
     */
    private function getUsersOffice($selection)
    {

        $users = null;
        $htmlOffices = [];
        //Si es admin se obtienen todos los users
        if (Auth::user()->isAdmin()) {
            $users = User::where('active', 1)->get();
            if ($users) {
                foreach ($users as $user) {
                    $userId = $user->id;
                    $office = Office::where('id', $selection)->first();
                    $htmlOffices[] = $this->getHtmlEntity($office->masters(), $user);
                }
            }
        } else {
            //Buscar los usuarios asignados al equipo
            $user = Auth::user();
            $offices = $this->getUsersEntityAsigned($user, Office::class);
            foreach ($offices as $office) {
                $htmlOffices[] = $this->getHtmlEntity($office, $user);
            }
        }
        return $htmlOffices;
    }


    /**
     * @param $list
     * @param $selection
     * @return string
     * @throws GeneralException
     */
    private function addUsersOffice($list, $selection)
    {
        $office = Office::where('id', $selection)->first();
        return $this->saveUsersEntity($office, $list);
    }

        /**
     * @param $selection
     * @return array
     */
    private function getUsers($selection)
    {
        $users = null;
        $htmlUsers = [];
        //Buscar los usuarios sin equipo o asignados al equipo
        $users = User::where('active', 1)
        ->where('team_id', $selection)
        ->orWhere('team_id', null)->get();
        if ($users) {
            foreach ($users as $user) {
                //Obtener el equipo
                $selected = '';
                $team = $user->myTeam;
                if ($team) {
                    if ($team->id == $selection) {
                        $selected = 'selected';
                    }
                }
                $userId = $user->id;
                $htmlUsers[] = ['value' => $userId,
                'text' => $userId . ' ' . htmlentities($user->username . ' ' . $user->name . ' ' . $user->last_name . ' ' . $user->last_name_2),
                'selected' => $selected];
            }
        }
        return $htmlUsers;
    }

    /**
     * @param $list
     * @param $selection
     * @throws Exception
     */
    private function addUsers($list, $selection)
    {
        try {
            $team = Team::where('id', $selection)->first();
            $officeId = null;
            if ($team) {
                $office = $team->myOffice;
                $delegation = null;
                if ($office) {
                    $company = null;
                    $delegation = $office->myDelegation;
                    if ($delegation) {
                        $company = $delegation->myCompany;
                    }
                }
                //Obtener los usuarios de ese equipo y ponerlos a null
                $usersTeam = $team->users;
                foreach($usersTeam as $userTeam) {
                    $userTeam->update(['team_id' => null]);
                    $userTeam->update(['office_id' => null]);
                    $userTeam->update(['delegation_id' => null]);
                    $userTeam->update(['company_id' => null]);
                    $userTeam->save();
                }
                if ($list) {
                    foreach ($list as $userId) {
                        $result = User::where('id', $userId)->update(['team_id' => $selection]);
                        if ($office) {
                            $result = User::where('id', $userId)->update(['office_id' => $office->id]);
                        }
                        if ($delegation) {
                            $result = User::where('id', $userId)->update(['delegation_id' => $delegation->id]);
                        }
                        if ($company) {
                            $result = User::where('id', $userId)->update(['company_id' => $company->id]);
                        }
                    }
                }
            }
        } catch (Exception $e) {;
            throw new Exception(__('auth.general_error'));
        }
    }
}
