<?php

namespace App\Services;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Interfaces\StatusInterface;
use Illuminate\Http\Request;
use App\Http\Requests\Backend\MessageRequest;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use App\Models\Message;
use Illuminate\Validation\ValidationException;
use App\Exceptions\GeneralException;
use Exception;
use Carbon\Carbon;

/**
 * Class MessageService.
 */
class MessageService implements StatusInterface
{
    /**
     * @param MessageRequest $request
     * @return mixed
     */
    public function getJsonList(MessageRequest $request) {
        $users = null;
        $dataCollection = [];

        if (Auth::user()->isAdmin()) {
            $users = User::where('active', 1)->get();
        }
        if ($users) {
            foreach($users as $user) {
                $dataCollection[]  = [
                    'id'         => $user->id,
                    'username'   => $user->username,
                    'name'       => $user->name.' '.$user->last_name.' '.$user->last_name2,
                    'company'    => isset($user->myCompany) ? $user->myCompany->name : '',
                    'team'       => isset($user->myTeam) ? $user->myTeam->name : ''
                ];
            }
            return [self::SUCCESS => self::SUCCESS, 'data' => $dataCollection];
        }
        return [self::SUCCESS => self::SUCCESS];
    }

    /**
     * @param MessageRequest $request
     * @return array|null
     * @throws GeneralException
     * @throws ValidationException
     */
    public function send(MessageRequest $request) {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            $message = new Message();
            $message = $this->manageMessage($request, $message, $data);
            //Logs
            Log::info('Enviado el mensaje '.$message->id);
            DB::commit();
            return [self::SUCCESS => self::SUCCESS];
            //return false;
        } catch (ValidationException $e) {
                throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
            throw new GeneralException(__('auth.general_error'));
        }
        return null;
    }


    /**
     * @param $request
     * @param $message
     * @param $data
     * @return mixed
     */
    private function manageMessage($request, $message, $data) {
        $text = isset($data['message']) ? $data['message'] : null;

        $textClean = strip_tags($text);
        $textClean = preg_replace("/\xEF\xBB\xBF/", "", $textClean);
        if (strlen($textClean) == 0) {
            $text = '';
        }
        $message->text = $text;
        $message->color = isset($data['color']) ? $data['color'] : null;
        $message->priority = isset($data['range']) ? $data['range'] : null;
        $message->sender_id = Auth::User()->id;
        $message->Save();
        $userIds = isset($data['ids']) ? $data['ids'] : null;
        $message->users()->attach($userIds);
        $message->Save();
        return $message;
    }

        /**
     * @param Request $request
     * @return mixed
     */
    public function search(Request $request) {
        $users = null;
        $dataCollection = [];

        $user = Auth::User();
        if ($user) {
            $messages = $user->messages()->where('read_at', NULL)->get();
            foreach($messages as $message) {
                $image = $message->mySender->getavatar();
                $senderName = isset($message->mySender) ? $message->mySender->name : '';
                $dataCollection[]  = [
                    'id'         => $message->id,
                    'username'   => $senderName,
                    'text'       => $message->text,
                    'color'      => isset($message->color) ? $message->color : '#ffc107',
                    'priority'   => isset($message->priority) ? $message->priority : 0,
                    'created_at' => Carbon::parse($message->created_at)->diffForHumans(),
                    'image'  => $image,
                ];
            }
            return [self::SUCCESS => self::SUCCESS, 'data' => $dataCollection];
        }
        return [self::SUCCESS => self::SUCCESS];
    }

            /**
     * @param Request $request
     * @return mixed
     */
    public function delete(Request $request) {
        $users = null;
        $data = $request->all();

        $id = isset($data['message-id']) ? $data['message-id'] : null;

        $user = Auth::User();
        $deleteMessage = Message::where('id', $id)->first();
        //Obtener los mensajes enviados al usuario
        $messagesUser =  $user->messages()->where('read_at', NULL)->get();
        foreach($messagesUser as $messageUser) {
            if ($messageUser->id == $deleteMessage->id) {
                $deleteMessage->update(['read_at' => now()]);
            }
        }
        return [self::SUCCESS => self::SUCCESS, 'delete' => true];
    }
}
