<?php

namespace App\Services;

use Illuminate\Contracts\Validation\Validator;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use App\Events\User\UserUpdated;
use App\Events\User\UserCreated;
use App\Events\User\UserDeleted;
use App\Events\User\UserDestroyed;
use App\Models\Company;
use App\Models\Team;
use App\Models\Office;
use App\Models\Delegation;
use App\Models\User;
use Illuminate\Support\Facades\Log;
use Illuminate\Http\Request;
use Illuminate\Support\Collection;
use App\Http\Requests\Backend\UserRequest;
use App\Exceptions\GeneralException;
use Illuminate\Support\Facades\Storage;
use Illuminate\Validation\ValidationException;
use Image;
use Exception;
use Throwable;
use Carbon\Carbon;
use DataTables;
use App\Services\HelperService;

/**
 * Class UserService.
 */
class UserService
{
/**
     * @param User $user
     *
     * @return bool
     */
    public function delete(User $user): bool
    {
        try {
            DB::beginTransaction();

            //Borrar la empresa
            $user->delete();
            $user->Save();
            //Logs
            Log::info('Borrado el usuario '.$user->id);
            event(new UserDeleted($user));
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

        /**
     * @param User $user
     *
     * @return bool
     */
    public function deleteImage(User $user): bool
    {
        try {
            DB::beginTransaction();
            $user->image_location=NULL;
            $user->Save();
            //Logs
            Log::info('Borrada la imagen '.$user->id);
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

    /**
     * @param User $user
     *
     * @return bool
     */
    public function destroy(User $user): bool
    {
        try {
            DB::beginTransaction();
            $this->delete($user);
            $user->forceDelete();
            //Logs
            Log::info('Destruida el usuario '.$user->id);
            event(new UserDestroyed($user));
            DB::commit();
            return true;
        } catch (Exception $e) {
            Log::error($e);
            DB::rollBack();
        }
        return false;
    }

             /**
     * @param  UserRequest $request
     *
     * @return User
     * @throws GeneralException
     * @throws Throwable
     */
    public function updateUser(UserRequest $request): ?User
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            //Buscar el usuario
            $user = null;
            $userId = isset($data['user-id']) ? $data['user-id'] : null;
            if ($userId) {
                $user = User::where('id', $userId)->first();
                if ($user) {
                    $user = $this->manageUser($request, $user, $data);
                }
            }
            //Logs
            Log::info('Actualizado el usuario '.$user->id);
            event(new UserUpdated($user));
            DB::commit();
            return $user;
        } catch (ValidationException $e) {
            throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }


     /**
     * @param  UserRequest $request
     *
     * @return User
     * @throws GeneralException
     * @throws Throwable
     */
    public function createUser(UserRequest $request): ?User
    {
        try {
            DB::beginTransaction();
            //Insertar datos
            $data = $request->all();
            $user = new User();
            $user = $this->manageUser($request, $user, $data);
            //Logs
            Log::info('Creado el usuario '.$user->id);
            event(new UserCreated($user));
            DB::commit();
            return $user;
            //return false;
        } catch (ValidationException $e) {
                throw new ValidationException($e->validator);
        } catch (Exception $e) {
            Log::error($e);
            throw new GeneralException(__('auth.general_error'));
            DB::rollBack();
        }
        return null;
    }



    /**
     * @param UserRequest $request
     * @param User $user
     *
     * @param $data
     * @return User
     * @throws ValidationException
     */
    private function manageUser($request, $user, $data) {
        $user->code = isset($data['code']) ? $data['code'] : null;
        $user->locale = isset($data['locale']) ? $data['locale'] : null;
        $type = isset($data['type']) ? $data['type'] : null;
        if ($type) {
            $user->type = $type;
        }
        $contract = isset($data['contract']) ? $data['contract'] : null;
        if ($contract) {
            $user->contract = $contract;
        }
        $user->contract_hours = isset($data['contract_hours']) ? strtolower($data['contract_hours']) : null;
        $user->name = isset($data['name']) ? $data['name'] : null;
        $username = isset($data['username']) ? strtolower($data['username']) : null;
        if (!$username) {
            $username = str_slug($data['name'], "-");
        }
        $user->username = $username;
        $password = isset($data['password']) ? $data['password'] : null;
        if ($password) {
            $user->password = Hash::make($password);
        }
        $user->last_name = isset($data['last_name']) ? $data['last_name'] : null;
        $user->last_name_2 = isset($data['last_name_2']) ? $data['last_name_2'] : null;
        $user->phone = isset($data['phone']) ? $data['phone'] : null;
        $user->mobile = isset($data['mobile']) ? $data['mobile'] : null;
        $user->email = isset($data['email']) ? $data['email'] : null;
        $user->company_id = isset($data['company']) ? $data['company'] : null;
        $teamId = isset($data['team']) ? $data['team'] : null;
        if ($teamId) {
            $user->team_id = $teamId;
            //Insertar delegacion y oficina
            $team = Team::where('id', $teamId)->first();
            if ($team) {
                $office = $team->myOffice;
                if ($office) {
                    $user->office_id = $office->id;
                    $delegation = $office->myDelegation;
                    if ($delegation) {
                        $user->delegation_id = $delegation->id;
                        $company = $delegation->myCompany;
                        if ($company) {
                            //Se cambia la empresa
                            $user->company_id = $company->id;
                        } else {
                            throw ValidationException::withMessages(['team' => __('backend.company.error.company')]);
                        }
                    } else {
                        throw ValidationException::withMessages(['team' => __('backend.company.error.delegation')]);
                    }
                } else {
                    throw ValidationException::withMessages(['team' => __('backend.company.error.office')]);
                }
            }
        }

        $nif = isset($data['nif']) ? $data['nif'] : null;
        if (!HelperService::validateNif($nif)) {
            throw new GeneralException(__('auth.general_error'));
        }
        $user->nif = $nif;
        $iban = isset($data['iban']) ? $data['iban'] : null;
        $account = isset($data['account']) ? $data['account'] : null;
        $cuenta = strtoupper($iban.$account);
        if (!HelperService::validateAccount($cuenta)) {
            throw new GeneralException(__('auth.general_error'));
        }
        $user->account = $cuenta;

        $user->active = isset($data['active']) ? $data['active'] : false;

        $user->Save();
        $userId = $user->id;
        //Insertar avatar
        if ($request->hasFile('avatar')) {
            $file = $request->file('avatar');
            $filename = HelperService::uploadFile($file, 'uavatar', $userId);
            $user->image_location = $filename;
        }
        $user->Save();
        return $user;
    }

    /**
     * @param Request $request
     * @return mixed
     */
    public function getJsonList(Request $request) {
        $data = new Collection;

        $users = User::all()->sortByDesc("id");
        foreach($users as $user) {
            $data->push([
                'username'   => $user->username,
                'id'         => $user->id,
                'type'       => $user->type,
                'email'      => $user->email,
                'company'    => isset($user->myCompany->name) ? $user->myCompany->name :  false,
                'team'       => isset($user->myTeam->name) ? $user->myTeam->name : false,
                'active'     => $user->active,
                'diff'       => Carbon::parse($user->updated_at)->diffForHumans(),
            ]);
        }

        if ($users) {
            return DataTables::of($data)
                ->addColumn('action', function($data){

                    $id = isset($data['id']) ? $data['id'] : -1;
                    $routeShow =  route('admin.auth.user.user.show', ['user' => $id]);
                    $routeEdit =  route('admin.auth.user.user.edit', ['user' => $id]);
                    $routeDelete = route('admin.auth.user.user.delete', ['user' => $id]);
                    $slug = isset($data['username']) ? $data['username'] : -1;
                    $buttons = '<a href="'.$routeShow.'" type="button" name="view" class="btn btn-info btn-sm view"><i class="fas fa-search"> '.trans('backend.button.view').'</i></a>
                    <a href="'.$routeEdit.'" type="button" name="edit" class="btn btn-primary btn-sm edit"><i class="fas fa-pencil-alt"> '.trans('backend.button.edit').'</i></a> ';
                    if ($id > 1) {
                        $buttons .= '<button attr-delete="'.$routeDelete.'" type="button" name="delete" attr-id="'.$id.'" attr-slug="'.$slug.'" class="btn btn-danger btn-sm delete"><i class="fas fa-trash"></i> '.trans('backend.button.delete').'</button>';
                    }
                    return $buttons;
                })
                ->addColumn('active-icon', function($data){
                    return HelperService::getIcon($data['active'], false);
                })
                ->addColumn('company-icon', function($data){
                    return HelperService::getIcon($data['company']);
                })
                ->addColumn('team-icon', function($data){
                    return HelperService::getIcon($data['team']);
                })
                ->rawColumns(['action' => 'active-icon', 'company' => 'company-icon', 'team' => 'team-icon'])
                ->make(true);
        }
        return DataTables::of(new Collection);
    }
}
