<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;
use App\Models\RegisterState;

class CreateRegisterStatesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('register_states', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->unsignedBigInteger('user_id');
            $table->unsignedBigInteger('company_id');
            $table->enum('state_type', array(Register::REGISTER_TYPE_START, Register::REGISTER_TYPE_STOP,  Register::REGISTER_TYPE_RETURN, Register::REGISTER_TYPE_FINISH, Register::REGISTER_TYPE_HOLIDAYS, Register::REGISTER_TYPE_CLOSED ));
            $table->enum('state', [RegisterState::REGISTER_STATE_PDTE, RegisterState::REGISTER_STATE_OK, RegisterState::REGISTER_STATE_KO])->default(RegisterState::REGISTER_STATE_PDTE);
            $table->text('comments')->nullable();
            $table->unsignedTinyInteger('closed')->default(0);
            $table->timestamps();
            $table->softDeletes();

            $table->foreign('user_id')->references('id')->on('users');
            $table->foreign('company_id')->references('id')->on('companies');
        });


        Schema::table('registers', function (Blueprint $table) {
            $table->foreign('register_state_id')->references('id')->on('register_states');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('register_states', function (Blueprint $table) {
            $table->dropForeign('register_states_company_id_foreign');
            $table->dropForeign('register_states_user_id_foreign');
        });

        Schema::dropIfExists('register_states');
    }
}
