<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;
use App\Models\Lead;

class CreateLeadsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('leads', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('identificator')->unique();
            $table->string('external_reference')->nullable();
            $table->datetime('signature_date')->nullable();
            $table->datetime('closed_date')->nullable();
            $table->unsignedBigInteger('user_id')->nullable();
            $table->unsignedBigInteger('team_id')->nullable();
            $table->unsignedBigInteger('company_id')->nullable();
            $table->unsignedBigInteger('office_id')->nullable();
            $table->unsignedBigInteger('delegation_id')->nullable();
            $table->unsignedBigInteger('client_id')->nullable();
            $table->enum('status', array(LEAD::REGISTER_TYPE_PDTE, LEAD::REGISTER_TYPE_OK, LEAD::REGISTER_TYPE_KO))->default(LEAD::REGISTER_TYPE_PDTE);
            $table->boolean('closed')->nullable()->default(0);
            $table->text('comments')->nullable();
            $table->timestamps();
            $table->softDeletes();

            $table->foreign('user_id')->references('id')->on('users')->onDelete('restrict')->onUpdate('cascade');
            $table->foreign('company_id')->references('id')->on('companies')->onDelete('restrict')->onUpdate('cascade');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        $table->dropForeign('leads_user_id_foreign');
        $table->dropForeign('leads_company_id_foreign');
        Schema::dropIfExists('leads');
    }
}
