<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateDelegationsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('delegations', function (Blueprint $table) {
            $table->id();
            $table->unsignedBigInteger('company_id')->nullable();
            $table->string('name')->nullable();
            $table->string('slug')->nullable();
            $table->string('image_location')->nullable();
            $table->unsignedTinyInteger('active')->default(1);
            $table->timestamps();
            $table->softDeletes();

            $table->foreign('company_id')->references('id')->on('companies')->onDelete('set null');
        });


        Schema::table('users', function (Blueprint $table) {
            $table->foreign('delegation_id')->references('id')->on('delegations')->onDelete('set null');
        });


        Schema::table('leads', function (Blueprint $table) {
            $table->foreign('delegation_id')->references('id')->on('delegations')->onDelete('restrict')->onUpdate('cascade');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('delegations');

        Schema::table('users', function (Blueprint $table) {
            $table->dropForeign('users_delegation_id_foreign');
        });

        Schema::table('leads', function (Blueprint $table) {
            $table->dropForeign('leads_delegation_id_foreign');
        });

        $table->dropForeign('delegations_company_id_foreign');
    }
}
