<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateOfficesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('offices', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->unsignedBigInteger('delegation_id')->nullable();
            $table->string('name')->nullable();
            $table->string('slug')->nullable();
            $table->string('image_location')->nullable();
            $table->unsignedTinyInteger('active')->default(1);
            $table->timestamps();
            $table->softDeletes();

            $table->foreign('delegation_id')->references('id')->on('delegations')->onDelete('set null');
        });

        Schema::table('users', function (Blueprint $table) {
            $table->foreign('office_id')->references('id')->on('offices')->onDelete('set null');
        });

        Schema::table('teams', function (Blueprint $table) {
            $table->foreign('office_id')->references('id')->on('offices')->onDelete('set null');
        });

        Schema::table('leads', function (Blueprint $table) {
            $table->foreign('office_id')->references('id')->on('offices')->onDelete('restrict')->onUpdate('cascade');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('users', function (Blueprint $table) {
            $table->dropForeign('users_office_id_foreign');
        });

        Schema::table('teams', function (Blueprint $table) {
            $table->dropForeign('teams_office_id_foreign');
        });

        $table->dropForeign('offices_delegation_id_foreign');

        Schema::table('leads', function (Blueprint $table) {
            $table->foreign('office_id')->references('id')->on('offices')->onDelete('restrict')->onUpdate('cascade');
        });

        $table->dropForeign('leads_office_id_foreign');

        Schema::dropIfExists('offices');
    }
}
