@extends('front.layouts.auth')

@section('title', __('Register'))

@section('auth')
<div class="col-md-5">
    <img src="{{ asset('/images/front/login.jpg') }}" alt="login" class="login-card-img">
</div>

<div class="col-md-7">
    <div class="card-body">
        <div class="login-brand-wrapper">
            <img src="{{ asset('/images/front/logo.png') }}" alt="logo" class="logo">
        </div>
        <p class="login-card-description">{{ __('Register') }}</p>
        <form id="auth-form" method="POST" action="{{ route('front.register') }}">
            @csrf
            <div class="form-group">
                <label for="username" class="sr-only">{{ __('front.username') }}</label>
                <input id="username" type="username" class="form-control @error('username') is-invalid @enderror"
                 maxlength="150" onKeyDown="if(this.value.length>150 ) return false;"
                    placeholder="{{ __('front.username') }}" name="username" value="{{ old('username') }}" required
                    autocomplete="username" autofocus>
                @error('username')
                <span class="invalid-feedback" role="alert">
                    <strong>{{ $message }}</strong>
                </span>
                @enderror
            </div><!--form-group-->

            <div class="form-group">
                <label for="email" class="sr-only">{{ __('E-Mail Address') }}</label>
                <input id="email" type="email" class="form-control @error('email') is-invalid @enderror"
                    maxlength="150"
                    placeholder="{{ __('E-Mail Address') }}" name="email" value="{{ old('email') }}" required
                    autocomplete="email" autofocus>
                @error('email')
                <span class="invalid-feedback" role="alert">
                    <strong>{{ $message }}</strong>
                </span>
                @enderror
            </div><!--form-group-->

            <div class="form-group mb-4">
                <label for="password" class="sr-only">{{ __('Password') }}</label>
                <input id="password" type="password" placeholder="{{ __('Password') }}"
                    class="form-control @error('password') is-invalid @enderror" name="password" required
                    autocomplete="current-password">
                @error('password')
                <span class="invalid-feedback" role="alert">
                    <strong>{{ $message }}</strong>
                </span>
                @enderror
            </div><!--form-group-->

            <div class="form-group mb-4">
                <label for="password-confirm" class="sr-only">{{ __('Confirm Password') }}</label>
                <input id="password-confirm" type="password" placeholder="{{ __('Confirm Password') }}"
                    class="form-control" name="password_confirmation" required
                    autocomplete="new-password">
            </div><!--form-group-->

            @if(config('boilerplate.access.captcha.login'))
                <div class="row">
                    <div class="col">
                        @captcha
                        <input type="hidden" name="captcha_status" value="true" />
                    </div><!--col-->
                </div><!--row-->
            @endif

            <div class="form-group">
                <button type="submit" class="btn btn-block login-btn mb-4">{{ __('Register') }}</button>
            </div><!--form-group-->

        </form>
        @include('auth.includes.terms')
    </div>
</div>
@endsection
@push('after-scripts')
    @include('auth.includes.lang')
    <script src="{{ asset('js/front/login.js') }}"></script>
@endpush
