@extends('backend.includes.partials.wrapper')

@push('after-styles')

@endpush

@isset($announcement)
@section('title', __('backend.announcement.actions.edit'))
@else
@section('title', __('backend.announcement.actions.create'))
@endisset

@section('content-wrapper')
    <!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">@isset($announcement){{ ucfirst( __('backend.announcement.actions.edit') ) }}@else @section('title', __('backend.announcement.actions.create')) @endisset</h1>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->
    <!-- Main content -->
    <div class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
            <div class="col-md-12">
                <div class="card card-primary">
                    <div class="card-header">
                      <h3 class="card-title">@isset($announcement){{ ucfirst( __('backend.announcement.actions.edit') ) }}@else @section('title', __('backend.announcement.actions.create')) @endisset</h3>

                      <div class="card-tools">
                        <div class="input-group input-group-sm" style="width: 150px;">
                          <div class="input-group-append">
                            <a href="{{ url()->previous() }}"><i class="fas fa-arrow-left"> {{ __('backend.announcement.actions.back') }}</i></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <!-- form start -->
                    <form id="create-form-entity" method="POST" @isset($announcement) action="{{ route('admin.auth.announcement.announcement.update') }}" @else action="{{ route('admin.auth.announcement.announcement.store') }}" @endisset enctype="multipart/form-data">
                        @csrf
                        @isset($announcement)
                            <input type="hidden" name="announcement-id" value="{{ $announcement->id}}">
                        @endif
                        <div class="card-body">
                            @include('backend.includes.partials.announcementarea')
                            @include('backend.includes.partials.announcementtype')
                            <div class="form-group row">
                                <label for="message" class="col-sm-2 col-form-label">{{ __('backend.announcement.form.message')}}</label>
                                <div class="col-sm-8">
                                    <textarea type="text" maxlength="1000" name="message" class="form-control" autocomplete="off" id="message" placeholder="{{ __('backend.announcement.form.message')}}">@if (old('message')!=null)  @php echo old('message') @endphp @else @isset($announcement) {{ $announcement->message }} @endisset @endif</textarea>
                                    @error('message')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="start" class="col-sm-2 col-form-label">{{ __('backend.announcement.form.starts_at')}}</label>
                                <div class="col-sm-8">
                                    <input required type="datetime" name="start" class="form-control"
                                    data-inputmask-alias="datetime"
                                    data-inputmask-inputformat="dd/mm/yyyy HH:ss" data-mask
                                    autocomplete="off" required id="start"
                                    @if (old('start')!=null) value="{{ old('start') }}" @else @isset($announcement->starts_at) value="{{ \Carbon\Carbon::parse($announcement->starts_at)->format('d/m/Y H:i') }}" @endisset @endif>
                                    @error('start')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="end" class="col-sm-2 col-form-label">{{ __('backend.announcement.form.ends_at')}}</label>
                                <div class="col-sm-8">
                                    <input required type="datetime" name="end" class="form-control"
                                    data-inputmask-alias="datetime"
                                    data-inputmask-inputformat="dd/mm/yyyy HH:ss" data-mask
                                    autocomplete="off" required id="end"
                                    @if (old('end')!=null) value="{{ old('end') }}" @else  @isset($announcement->ends_at) value="{{ \Carbon\Carbon::parse($announcement->ends_at)->format('d/m/Y H:i') }}" @endisset @endif>
                                    @error('end')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="enabled" class="col-sm-2 col-form-label">{{ __('backend.announcement.form.active')}}</label>
                                <div class="col-sm-8">
                                    <input type="checkbox" autocomplete="off" id="enabled" name="enabled" value="1" @if(old('enabled')) @if (old('enabled')==1) checked @else  @endif @else @isset($announcement) {{ ( $announcement->enabled==1) ? "checked" : "" }} @endisset @endif>
                                </div>
                            </div>
                        </div>
                        <!-- /.card-body -->
                        <div class="card-footer">
                        <button type="submit" class="btn btn-primary">@isset($announcement) {{ __('backend.announcement.actions.edit') }} @else {{ __('backend.announcement.actions.create') }}@endif</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
        <!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content -->
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('vendor/tinymce/tinymce.min.js') }}"></script>
<script src="{{ asset('plugins/inputmask/jquery.inputmask.min.js') }}"></script>
<script src="{{ asset('js/backend/announcement.js') }}"></script>
@include('auth.includes.editor')
<script>
    $('[data-mask]').inputmask('dd/mm/yyyy HH:ss', {
        'placeholder': 'dd/mm/yyyy HH:SS'
    });

    if ($("#start").val() == '') {
        $("#start").val(moment(new Date()).format("DD/MM/YYYY HH:mm"));
    }

    if ($("#end").val() == '') {
        $("#end").val(moment(new Date()).format("DD/MM/YYYY HH:mm"));
    }

</script>
<!-- Page specific script -->
@endpush
