@extends('backend.includes.partials.wrapper')

@isset($campaign)
@section('title', __('backend.campaign.actions.edit'))
@else
@section('title', __('backend.campaign.actions.create'))
@endisset

@section('content-wrapper')
    <!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">@isset($campaign){{ ucfirst( __('backend.campaign.actions.edit') ) }}@else @section('title', __('backend.campaign.actions.create')) @endisset</h1>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->
    <!-- Main content -->
    <div class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
            <div class="col-md-12">
                <div class="card card-primary">
                    <div class="card-header">
                      <h3 class="card-title">@isset($campaign){{ ucfirst( __('backend.campaign.actions.edit') ) }}@else @section('title', __('backend.campaign.actions.create')) @endisset</h3>

                      <div class="card-tools">
                        <div class="input-group input-group-sm" style="width: 150px;">
                          <div class="input-group-append">
                            <a href="{{ url()->previous() }}"><i class="fas fa-arrow-left"> {{ __('backend.campaign.actions.back') }}</i></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <!-- form start -->
                    <form id="create-form-entity" method="POST" @isset($campaign) action="{{ route('admin.auth.campaign.campaign.update') }}" @else action="{{ route('admin.auth.campaign.campaign.store') }}" @endisset enctype="multipart/form-data">
                        @csrf
                        @isset($campaign)
                            <input type="hidden" name="campaign-id" value="{{ $campaign->id}}">
                        @endif
                        <div class="card-body">
                            <div class="form-group row">
                                <label for="name" class="col-sm-2 col-form-label">{{ __('backend.campaign.form.name')}}</label>
                                <div class="col-sm-4">
                                    <input type="text" name="name" required maxlength="50" class="form-control" id="name" @if (old('name') != null) value="{{ old('name') }}" @else @isset($campaign))  value="{{ $campaign->name }}" @endisset @endif onKeyDown="if(this.value.length>50 & event.keyCode!==8) return false;" placeholder="{{ __('backend.campaign.form.name')}}">
                                    @error('name')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="company" class="col-sm-2 col-form-label">{{ __('backend.company.name')}}</label>
                                <div class="col-sm-2">
                                    <select name="company" class="form-control" required autocomplete="off">
                                        <option value=''>{{ __('backend.company.name')}}</option>
                                        @isset($companies) @foreach ($companies as $company)
                                        <option value="{{ $company->id }}"
                                            @if($company->id == old('company'))  selected="selected"
                                            @elseif (isset($delegation))
                                                @if($delegation->company_id == $company->id) selected="selected"  @endif
                                            @else
                                            @endif>{{ $company->name }}</option>
                                        @endforeach
                                        @endisset
                                    </select>
                                    @error('company')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @include('auth.includes.avatar', ['entity' => $campaign, 'avatarType' => 'caavatar'])
                        </div>
                        <!-- /.card-body -->
                        <div class="card-footer">
                        <button type="submit" class="btn btn-primary">@isset($campaign) {{ __('backend.campaign.actions.edit') }} @else {{ __('backend.campaign.actions.create') }}@endif</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
        <!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content -->
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('js/backend/entity.js') }}"></script>
@endpush
