@extends('backend.includes.partials.wrapper')

@isset($company)
@section('title', __('backend.company.actions.edit'))
@else
@section('title', __('backend.company.actions.create'))
@endisset

@section('content-wrapper')
    <!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">@isset($company){{ ucfirst( __('backend.company.actions.edit') ) }}@else @section('title', __('backend.company.actions.create')) @endisset</h1>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->
    <!-- Main content -->
    <div class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
            <div class="col-md-12">
                <div class="card card-primary">
                    <div class="card-header">
                      <h3 class="card-title">@isset($company){{ ucfirst( __('backend.company.actions.edit') ) }}@else @section('title', __('backend.company.actions.create')) @endisset</h3>

                      <div class="card-tools">
                        <div class="input-group input-group-sm" style="width: 150px;">
                          <div class="input-group-append">
                            <a href="{{ url()->previous() }}"><i class="fas fa-arrow-left"> {{ __('backend.company.actions.back') }}</i></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <!-- form start -->
                    <form id="create-form-entity" method="POST" @isset($company) action="{{ route('admin.auth.company.company.update') }}" @else action="{{ route('admin.auth.company.company.store') }}" @endisset enctype="multipart/form-data">
                        @csrf
                        @isset($company)
                            <input type="hidden" name="company-id" value="{{ $company->id}}">
                        @endif
                        <div class="card-body">
                            @include('auth.includes.entity', ['entity' => $company, 'countries'=> $countries])
                            @include('auth.includes.name', ['entity' => $company, 'hide' => $hide = true])
                            @include('auth.includes.address', ['entity' => $address])
                            <div class="form-group row">
                                <label for="web" class="col-sm-2 col-form-label">{{ __('url')}}</label>
                                <div class="col-sm-8">
                                    <input type="url" name="web" class="form-control" autocomplete="off" id="web" onKeyDown="if(this.value.length>150 ) return false;" @if (old('web') != null) value="{{ old('web') }}" @else @isset($company))  value="{{ $company->web }}" @endisset @endif placeholder="{{ __('url')}}" >
                                    @error('web')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @include('auth.includes.payment', ['entity' => $company])
                            @include('auth.includes.avatar', ['entity' => $company, 'avatarType' => 'cavatar'])
                            <div class="form-group row">
                                <label for="register" class="col-sm-2 col-form-label">{{ __('backend.company.form.register')}}</label>
                                <div class="col-sm-8">
                                    <textarea type="text" name="register" class="form-control" autocomplete="off" id="register" onKeyDown="if(this.value.length>500 & event.keyCode!==8) return false;" placeholder="{{ __('backend.company.form.register')}}">@if (old('register')!=null)  @php echo old('register') @endphp @else @isset($company) {{ $company->register }} @endisset @endif</textarea>
                                    @error('register')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="conditions" class="col-sm-2 col-form-label">{{ __('backend.company.form.conditions')}}</label>
                                <div class="col-sm-8">
                                    <textarea type="text" name="conditions" class="form-control" autocomplete="off" id="conditions" onKeyDown="if(this.value.length>500 & event.keyCode!==8) return false;" placeholder="{{ __('backend.company.form.conditions')}}">@if (old('register')!=null)  @php echo old('conditions') @endphp @else @isset($company) {{ $company->conditions }} @endisset @endif</textarea>
                                    @error('conditions')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <!-- /.card-body -->
                        <div class="card-footer">
                        <button type="submit" class="btn btn-primary">@isset($company) {{ __('backend.company.actions.edit') }} @else {{ __('backend.company.actions.create') }}@endif</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
        <!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content -->
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('js/backend/company.js') }}"></script>
@endpush
