@extends('backend.includes.partials.wrapper')

@isset($office)
@section('title', __('backend.office.actions.edit'))
@else
@section('title', __('backend.office.actions.create'))
@endisset

@section('content-wrapper')
    <!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">@isset($office){{ ucfirst( __('backend.office.actions.edit') ) }}@else @section('title', __('backend.office.actions.create')) @endisset</h1>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->
    <!-- Main content -->
    <div class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
            <div class="col-md-12">
                <div class="card card-primary">
                    <div class="card-header">
                      <h3 class="card-title">@isset($office){{ ucfirst( __('backend.office.actions.edit') ) }}@else @section('title', __('backend.office.actions.create')) @endisset</h3>

                      <div class="card-tools">
                        <div class="input-group input-group-sm" style="width: 150px;">
                          <div class="input-group-append">
                            <a href="{{ url()->previous() }}"><i class="fas fa-arrow-left"> {{ __('backend.office.actions.back') }}</i></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <!-- form start -->
                    <form id="create-form-entity" method="POST" @isset($office) action="{{ route('admin.auth.office.office.update') }}" @else action="{{ route('admin.auth.office.office.store') }}" @endisset enctype="multipart/form-data">
                        @csrf
                        @isset($office)
                            <input type="hidden" name="office-id" value="{{ $office->id}}">
                        @endif
                        <div class="card-body">
                            <div class="form-group row">
                                <label for="name" class="col-sm-2 col-form-label">{{ __('backend.office.form.name')}}</label>
                                <div class="col-sm-4">
                                    <input type="text" name="name" required maxlength="50" class="form-control" id="name" @if (old('name') != null) value="{{ old('name') }}" @else @isset($office))  value="{{ $office->name }}" @endisset @endif onKeyDown="if(this.value.length>50 & event.keyCode!==8) return false;" placeholder="{{ __('backend.office.form.name')}}">
                                    @error('name')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="delegation" class="col-sm-2 col-form-label">{{ __('backend.delegation.name')}}</label>
                                <div class="col-sm-2">
                                    <select name="delegation" class="form-control" required autocomplete="off">
                                        <option value=''>{{ __('backend.delegation.name')}}</option>
                                        @isset($delegations) @foreach ($delegations as $delegation)
                                        <option value="{{ $delegation->id }}"
                                            @if($delegation->id == old('delegation'))  selected="selected"
                                            @elseif (isset($office))
                                                @if($office->delegation_id == $delegation->id) selected="selected"  @endif
                                            @else
                                            @endif>{{ $delegation->name }}</option>
                                        @endforeach
                                        @endisset
                                    </select>
                                    @error('delegation')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @include('auth.includes.avatar', ['entity' => $office, 'avatarType' => 'oavatar'])
                        </div>
                        <!-- /.card-body -->
                        <div class="card-footer">
                        <button type="submit" class="btn btn-primary">@isset($office) {{ __('backend.office.actions.edit') }} @else {{ __('backend.office.actions.create') }}@endif</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
        <!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content -->
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('js/backend/entity.js') }}"></script>
@endpush
