@extends('backend.includes.partials.wrapper')

@isset($team)
@section('title', __('backend.team.actions.edit'))
@else
@section('title', __('backend.team.actions.create'))
@endisset

@section('content-wrapper')
    <!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">@isset($team){{ ucfirst( __('backend.team.actions.edit') ) }}@else @section('title', __('backend.team.actions.create')) @endisset</h1>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->
    <!-- Main content -->
    <div class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
            <div class="col-md-12">
                <div class="card card-primary">
                    <div class="card-header">
                      <h3 class="card-title">@isset($team){{ ucfirst( __('backend.team.actions.edit') ) }}@else @section('title', __('backend.team.actions.create')) @endisset</h3>

                      <div class="card-tools">
                        <div class="input-group input-group-sm" style="width: 150px;">
                          <div class="input-group-append">
                            <a href="{{ url()->previous() }}"><i class="fas fa-arrow-left"> {{ __('backend.team.actions.back') }}</i></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <!-- form start -->
                    <form id="create-form-entity" method="POST" @isset($team) action="{{ route('admin.auth.team.team.update') }}" @else action="{{ route('admin.auth.team.team.store') }}" @endisset enctype="multipart/form-data">
                        @csrf
                        @isset($team)
                            <input type="hidden" name="team-id" value="{{ $team->id}}">
                        @endif
                        <div class="card-body">
                            <div class="form-group row">
                                <label for="name" class="col-sm-2 col-form-label">{{ __('backend.team.form.name')}}</label>
                                <div class="col-sm-4">
                                    <input type="text" name="name" required maxlength="50" class="form-control" id="name" @if (old('name') != null) value="{{ old('name') }}" @else @isset($team))  value="{{ $team->name }}" @endisset @endif onKeyDown="if(this.value.length>50 & event.keyCode!==8) return false;" placeholder="{{ __('backend.team.form.name')}}">
                                    @error('name')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="office" class="col-sm-2 col-form-label">{{ __('backend.office.name')}}</label>
                                <div class="col-sm-2">
                                    <select name="office" class="form-control" required autocomplete="off">
                                        <option value=''>{{ __('backend.office.name')}}</option>
                                        @isset($offices) @foreach ($offices as $office)
                                        <option value="{{ $office->id }}"
                                            @if($office->id == old('office'))  selected="selected"
                                            @elseif (isset($team))
                                                @if($team->office_id == $office->id) selected="selected"  @endif
                                            @else
                                            @endif>{{ $office->name }}</option>
                                        @endforeach
                                        @endisset
                                    </select>
                                    @error('office')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @include('auth.includes.avatar', ['entity' => $team, 'avatarType' => 'tavatar'])
                        </div>
                        <!-- /.card-body -->
                        <div class="card-footer">
                        <button type="submit" class="btn btn-primary">@isset($team) {{ __('backend.team.actions.edit') }} @else {{ __('backend.team.actions.create') }}@endif</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
        <!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content -->
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('js/backend/entity.js') }}"></script>
@endpush
