@extends('backend.includes.partials.wrapper')

@isset($user)
@section('title', __('backend.user.actions.edit'))
@else
@section('title', __('backend.user.actions.create'))
@endisset

@section('content-wrapper')
    <!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">@isset($user){{ ucfirst( __('backend.user.actions.edit') ) }}@else @section('title', __('backend.user.actions.create')) @endisset</h1>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->
    <!-- Main content -->
    <div class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
            <div class="col-md-12">
                <div class="card card-primary">
                    <div class="card-header">
                      <h3 class="card-title">@isset($user){{ ucfirst( __('backend.user.actions.edit') ) }}@else @section('title', __('backend.user.actions.create')) @endisset</h3>

                      <div class="card-tools">
                        <div class="input-group input-group-sm" style="width: 150px;">
                          <div class="input-group-append">
                            <a href="{{ url()->previous() }}"><i class="fas fa-arrow-left"> {{ __('backend.user.actions.back') }}</i></a>
                          </div>
                        </div>
                      </div>
                    </div>
                    <!-- form start -->
                    <form id="create-form-entity" name="create-form-entity" method="POST" @isset($user) action="{{ route('admin.auth.user.user.update') }}" @else action="{{ route('admin.auth.user.user.store') }}" @endisset enctype="multipart/form-data">
                        @csrf
                        @isset($user)
                            <input type="hidden" name="user-id" value="{{ $user->id}}">
                        @endif
                        <div class="card-body">
                            @if ($logged_in_user->isSuperAdmin())
                            @include('backend.includes.partials.usertype')
                            @endif
                            <div class="form-group row">
                                <label for="locale" class="col-sm-2 col-form-label">{{ __('backend.user.form.locale')}}</label>
                                <div class="col-sm-1">
                                    <select name="locale" id="locale" class="form-control" required autocomplete="off">
                                        @foreach(config('boilerplate.locale.languages') as $code => $details)
                                        <option value="{{ $code }}"
                                        @if($code == old('locale')) selected="selected"
                                            @elseif (isset($user))
                                                @if($user->locale == $code) selected="selected" @endif
                                            @endif>{{ __(getLocaleName($code)) }}</option>
                                        @endforeach
                                    </select>
                                    @error('locale')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="username" class="col-sm-2 col-form-label">{{ __('backend.user.form.username')}}</label>
                                <div class="col-sm-2">
                                    <input type="text" name="username" maxlength="50" class="form-control" required id="username" @if (old('username') != null) value="{{ old('username') }}" @else @isset($user))  value="{{ $user->username }}" @endisset @endif onKeyDown="if(this.value.length>50 & event.keyCode!==8) return false;" placeholder="{{ __('backend.user.form.username')}}">
                                    @error('username')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @include('auth.includes.entity', ['entity' => $user, 'countries'=> $countries])
                            @include('auth.includes.name', ['entity' => $user])
                            @isset($user)
                            @else
                            <div class="form-group row">
                                <label for="password" class="col-sm-2 col-form-label">{{ __('backend.user.form.password')}}</label>
                                <div class="col-sm-8">
                                    <input type="password" name="password" class="form-control" autocomplete="off" required id="password" placeholder="{{ __('backend.user.form.password')}}" >
                                    @error('password')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="password_confirmation" class="col-sm-2 col-form-label">{{ __('backend.user.form.password_confirm')}}</label>
                                <div class="col-sm-8">
                                    <input type="password" name="password_confirmation" class="form-control" autocomplete="off" required id="password_confirmation" placeholder="{{ __('backend.user.form.password_confirm')}}" >
                                    @error('password_confirmation')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @endisset
                            <div class="form-group row">
                                <label for="company" class="col-sm-2 col-form-label">{{ __('backend.company.name')}}</label>
                                <div class="col-sm-2">
                                    <select name="company" class="form-control" required autocomplete="off">
                                        <option value=''>{{ __('backend.company.name')}}</option>
                                        @foreach ($companies as $company)
                                        <option value="{{ $company->id }}"
                                            @if($company->id == old('company'))  selected="selected"
                                            @elseif (isset($user))
                                                @if($user->company_id == $company->id) selected="selected"  @endif
                                            @else
                                            @endif>{{ $company->name }}</option>
                                        @endforeach
                                    </select>
                                    @error('company')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="team" class="col-sm-2 col-form-label">{{ __('backend.team.name')}}</label>
                                <div class="col-sm-2">
                                    <select name="team" class="form-control" autocomplete="off">
                                        <option value=''>{{ __('backend.team.name')}}</option>
                                        @isset($teams)
                                            @foreach ($teams as $team)
                                            <option value="{{ $team->id }}"
                                                @if($team->id == old('team'))  selected="selected"
                                                @elseif (isset($user))
                                                    @if($user->team_id == $team->id)  selected="selected"  @endif
                                                @else
                                                @endif>{{ $team->name }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                    @error('team')
                                    <span class="invalid-feedback d-block" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            @include('backend.includes.partials.usercontract', ['entity' => $user])
                            @include('auth.includes.payment', ['entity' => $user])
                            @include('auth.includes.avatar', ['entity' => $user, 'avatarType' => 'uavatar'])
                        </div>
                        <!-- /.card-body -->
                        <div class="card-footer">
                        <button type="submit" class="btn btn-primary">@isset($user) {{ __('backend.user.actions.edit') }} @else {{ __('backend.user.actions.create') }}@endif</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
        <!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content -->
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('js/backend/user.js') }}"></script>
@endpush
