@extends('front.layouts.main')

@section('title', __('front.hour.plural'))


@push('after-styles')
<link rel="stylesheet" href="{{ asset('plugins/summernote/summernote-bs4.min.css') }}">
<link rel="stylesheet" href="{{ asset('plugins/daterangepicker/daterangepicker.css') }}">
@endpush

@section('content')
<main>
    <div class="container py-4">
        <div class="row justify-content-center">
            <div class="col-md-12">
                <div class="card text-center">
                    <div class="card-header">{{ __('front.hour.link.manual') }}</div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <form id="create-form-entity" action="{{ route('front.hour.create') }}" name="register">
                                    <meta name="_token" content="{{ csrf_token() }}">
                                    <div class="row mt-4 mb-2">
                                        <div class="col-12">
                                            <span class="badge badge-light">{{ __('front.hour.form.date') }}</span>
                                            <input required type="text" name="manual-date" class="form-control"
                                                data-inputmask-alias="datetime"
                                                data-inputmask-inputformat="dd/mm/yyyy HH:ss" data-mask
                                                autocomplete="off" required id="manual-date" @if (old('manual-date')
                                                !=null) value="{{ old('manual-date') }}" @endif>
                                            @error('manual-date')
                                            <span class="invalid-feedback d-block" role="alert">
                                                <strong>{{ $message }}</strong>
                                            </span>
                                            @enderror
                                        </div>
                                    </div>
                                    @include('front.includes.partials.hourtype')
                                    <!-- /.row -->
                                    <div class="row pt-5">
                                        <div class="col-md-3 mx-auto">
                                            <a name="confirm-manual" id="confirm-manual" class="btn btn-app bg-warning"
                                            data="{{ __('front.hour.link.manual') }}">
                                            <i class="fas fa-play"></i>
                                            <span class="badge-pill bg-warning">{{ __('front.hour.name') }} {{ __('front.hour.link.manual') }} </span>
                                            </a>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-12">
                                <!-- /.row -->
                                <div class="row mt-4 mb-2">
                                    <div class="col-12">
                                        <span class="badge badge-light">{{ __('front.hour.form.comments') }}</span>
                                        <textarea maxlength="1000" id="summernote"></textarea>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</main>
@endsection
@push('after-scripts')
@include('auth.includes.lang')
<script src="{{ asset('plugins/summernote/summernote-bs4.min.js') }}"></script>
<script src="{{ asset('plugins/inputmask/jquery.inputmask.min.js') }}"></script>
<script src="{{ asset('js/front/hour.js') }}"></script>
<script>
    $(function () {
        // Summernote
        $('#summernote').summernote('justifyLeft');
        $('#summernote').summernote('fontName', 'Arial');
        $('#summernote').summernote('fontSize', 18);

        $('[data-mask]').inputmask('dd/mm/yyyy HH:ss', {
            'placeholder': 'dd/mm/yyyy HH:SS'
        })
        if ($("#manual-date").val() == '') {
            $("#manual-date").val(moment(new Date()).format("DD/MM/YYYY HH:mm"));
        }
    })

</script>
@endpush
