@extends('front.layouts.main')

@section('title', __('front.hour.plural'))


@push('after-styles')
@endpush

@section('content')
<main>
    <div class="container py-4">
        <div class="row justify-content-center">
            <div class="col-md-12">
                <div class="card text-center">
                    <div class="card-header">{{ __('front.hour.link.search') }}</div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <form id="create-form-entity" dt-action="{{ route('front.hour.find') }}" name="search">
                                    <meta name="_token" content="{{ csrf_token() }}">
                                    <div class="row mt-4 mb-2">
                                        <div class="col-12">
                                            <span class="badge badge-light">{{ __('front.hour.form.date_start') }}</span>
                                            <input required type="text" name="date-initial" id="date-initial" class="form-control"
                                                data-inputmask-alias="datetime"
                                                data-inputmask-inputformat="dd/mm/yyyy HH:ss" data-mask
                                                autocomplete="off" required @if (old('date-initial')
                                                !=null) value="{{ old('date-initial') }}" @endif>
                                            @error('date-initial')
                                            <span class="invalid-feedback d-block" role="alert">
                                                <strong>{{ $message }}</strong>
                                            </span>
                                            @enderror
                                        </div>
                                    </div>
                                    <div class="row mt-4 mb-2">
                                        <div class="col-12">
                                            <span class="badge badge-light">{{ __('front.hour.form.date_end') }}</span>
                                            <input required type="text" name="date-end" id="date-end" class="form-control"
                                                data-inputmask-alias="datetime"
                                                data-inputmask-inputformat="dd/mm/yyyy HH:ss" data-mask
                                                autocomplete="off" required @if (old('date-end')
                                                !=null) value="{{ old('date-end') }}" @endif>
                                            @error('date-end')
                                            <span class="invalid-feedback d-block" role="alert">
                                                <strong>{{ $message }}</strong>
                                            </span>
                                            @enderror
                                        </div>
                                    </div>
                                    <!-- /.row -->
                                    <div class="row pt-5">
                                        <div class="col-md-3 mx-auto">
                                            <a name="search-manual" name="search-manual" class="btn btn-app bg-success">
                                                {{ __('front.hour.button.search') }} {{ __('front.hour.plural') }}
                                            </a>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>
                        <div class="row mt-5">
                            <div class="col-md-12">
                                <table class="table table-bordered table-hover dt-responsive" width="100%" id="register-search">
                                    <thead>
                                        <tr>
                                            <th>{{ __('front.hour.form.date') }}</th>
                                            <th>{{ __('front.hour.form.start') }}</th>
                                            <th>{{ __('front.hour.form.stop') }}</th>
                                            <th>{{ __('front.hour.form.return') }}</th>
                                            <th>{{ __('front.hour.form.finish') }}</th>
                                            <th>{{ __('front.hour.form.status') }}</th>
                                            <th>{{ __('front.hour.form.type') }}</th>
                                            <th>{{ __('front.hour.form.company') }}</th>
                                        </tr>
                                    </thead>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</main>
@endsection
@push('after-scripts')
@php $dataTableLang = null;
    if (htmlLang() == 'es')  {
        $dataTableLang = "//cdn.datatables.net/plug-ins/1.10.21/i18n/Spanish.json";
    } elseif (htmlLang() == 'ca') {
        $dataTableLang = "//cdn.datatables.net/plug-ins/1.10.21/i18n/Catalan.json";
    }
@endphp
@include('auth.includes.lang')
<script src="{{ asset('plugins/inputmask/jquery.inputmask.min.js') }}"></script>
<script src="{{ asset('js/front/hour.js') }}"></script>
<script>
    $(function () {
        $('#register-search').DataTable(
        {
        order:[[0,"desc"]],
        dom: 'Bfrtip',
        buttons: [
            'copy', 'csv', 'excel', 'pdf', 'print'
        ],
        @php
        if (isset($dataTableLang)){
            @endphp
            "language": {
                "url": "{{ $dataTableLang }}"
            },
            @php
        }
        @endphp
        columns: [
            {data: 'date', name: 'date', defaultContent: ''},
            {data: 'start', name: 'start', defaultContent: ''},
            {data: 'stop', name: 'stop', defaultContent: ''},
            {data: 'return', name: 'return', defaultContent: ''},
            {data: 'finish', name: 'finish', defaultContent: ''},
            {data: 'status', name: 'status', defaultContent: ''},
            {data: 'type', name: 'type', defaultContent: ''},
            {data: 'company', name: 'company', defaultContent: ''},
            ]
        }
        );
    });
  </script>
<script>
    $(function () {

        $('[data-mask]').inputmask('dd/mm/yyyy HH:ss', {
            'placeholder': 'dd/mm/yyyy HH:SS'
        })
        if ($("#date-initial").val() == '') {
            $("#date-initial").val(new moment().startOf('month').format("01/MM/YYYY HH:mm"));
        }

        if ($("#date-end").val() == '') {
            $("#date-end").val(new moment().endOf('month').format("DD/MM/YYYY HH:mm"));
        }
    })
</script>
@endpush
