<?php

use App\Http\Controllers\Backend\UserController;
use App\Http\Controllers\Backend\CompanyController;
use App\Http\Controllers\Backend\TeamController;
use App\Http\Controllers\Backend\DelegationController;
use App\Http\Controllers\Backend\OfficeController;
use App\Http\Controllers\Backend\CompanyLinkController;
use App\Http\Controllers\Backend\LopdController;
use App\Http\Controllers\Backend\AnnouncementController;
use App\Http\Controllers\Backend\HourController;
use App\Http\Controllers\Backend\MasterController;
use App\Http\Controllers\Backend\MessageController;
use App\Http\Controllers\Backend\BackOfficeController;
use App\Http\Controllers\Backend\CampaignController;

// All route names are prefixed with 'admin.auth'.


Route::group([
    'prefix' => 'auth',
    'as' => 'auth.',
    'middleware' => config('boilerplate.access.middleware.confirm'),
], function () {
    Route::group([
        'prefix' => 'company',
        'as' => 'company.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [CompanyController::class, 'index'])->name('company.index');

            Route::get('list', [CompanyController::class, 'jsonList'])->name('company.jsonlist');
            Route::get('create', [CompanyController::class, 'create'])->name('company.create');
            Route::post('store', [CompanyController::class, 'store'])->name('company.store');
            Route::post('/', [CompanyController::class, 'update'])->name('company.update');

            Route::group(['prefix' => '{cia}'], function () {
                Route::get('edit', [CompanyController::class, 'edit'])->name('company.edit');
                Route::get('show', [CompanyController::class, 'show'])->name('company.show');
                Route::delete('/', [CompanyController::class, 'delete'])->name('company.delete');
                Route::delete('/delete-avatar', [CompanyController::class, 'deleteAvatar'])->name('company.delete.avatar');
            });
        });
    });

    Route::group([
        'prefix' => 'team',
        'as' => 'team.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [TeamController::class, 'index'])->name('team.index');

            Route::get('list', [TeamController::class, 'jsonList'])->name('team.jsonlist');
            Route::get('create', [TeamController::class, 'create'])->name('team.create');
            Route::post('store', [TeamController::class, 'store'])->name('team.store');
            Route::post('save', [TeamController::class, 'saveUser'])->name('team.saveuser');
            Route::post('search', [TeamController::class, 'search'])->name('team.search');
            Route::post('/', [TeamController::class, 'update'])->name('team.update');

            Route::group(['prefix' => '{team}'], function () {
                Route::get('edit', [TeamController::class, 'edit'])->name('team.edit');
                Route::get('show', [TeamController::class, 'show'])->name('team.show');
                Route::delete('/', [TeamController::class, 'delete'])->name('team.delete');
                Route::delete('/delete-avatar', [TeamController::class, 'deleteAvatar'])->name('team.delete.avatar');
            });
        });
    });

    Route::group([
        'prefix' => 'company-link',
        'as' => 'company-link.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {

            Route::get('list', [CompanyLinkController::class, 'jsonList'])->name('company-link.jsonlist');
            Route::get('create', [CompanyLinkController::class, 'create'])->name('company-link.create');
            Route::post('store', [CompanyLinkController::class, 'store'])->name('company-link.store');

            Route::group(['prefix' => '{link}'], function () {
                Route::get('edit', [CompanyLinkController::class, 'edit'])->name('company-link.edit');
                Route::get('show', [CompanyLinkController::class, 'show'])->name('company-link.show');
                Route::patch('/', [CompanyLinkController::class, 'update'])->name('company-link.update');
                Route::delete('/', [CompanyLinkController::class, 'delete'])->name('company-link.delete');
            });
        });
    });

    Route::group([
        'prefix' => 'delegation',
        'as' => 'delegation.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [DelegationController::class, 'index'])->name('delegation.index');

            Route::get('list', [DelegationController::class, 'jsonList'])->name('delegation.jsonlist');
            Route::get('create', [DelegationController::class, 'create'])->name('delegation.create');
            Route::post('store', [DelegationController::class, 'store'])->name('delegation.store');
            Route::post('/', [DelegationController::class, 'update'])->name('delegation.update');

            Route::group(['prefix' => '{delegation}'], function () {
                Route::get('edit', [DelegationController::class, 'edit'])->name('delegation.edit');
                Route::get('show', [DelegationController::class, 'show'])->name('delegation.show');
                Route::delete('/', [DelegationController::class, 'delete'])->name('delegation.delete');
                Route::delete('/delete-avatar', [DelegationController::class, 'deleteAvatar'])->name('delegation.delete.avatar');
            });
        });
    });

    Route::group([
        'prefix' => 'office',
        'as' => 'office.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [OfficeController::class, 'index'])->name('office.index');

            Route::get('list', [OfficeController::class, 'jsonList'])->name('office.jsonlist');
            Route::get('create', [OfficeController::class, 'create'])->name('office.create');
            Route::post('store', [OfficeController::class, 'store'])->name('office.store');
            Route::post('/', [OfficeController::class, 'update'])->name('office.update');

            Route::group(['prefix' => '{office}'], function () {
                Route::get('edit', [OfficeController::class, 'edit'])->name('office.edit');
                Route::get('show', [OfficeController::class, 'show'])->name('office.show');
                Route::delete('/', [OfficeController::class, 'delete'])->name('office.delete');
                Route::delete('/delete-avatar', [OfficeController::class, 'deleteAvatar'])->name('office.delete.avatar');
            });
        });
    });


    Route::group([
        'prefix' => 'campaign',
        'as' => 'campaign.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [CampaignController::class, 'index'])->name('campaign.index');

            Route::get('list', [CampaignController::class, 'jsonList'])->name('campaign.jsonlist');
            Route::get('create', [CampaignController::class, 'create'])->name('campaign.create');
            Route::post('store', [CampaignController::class, 'store'])->name('campaign.store');
            Route::post('/', [CampaignController::class, 'update'])->name('campaign.update');

            Route::group(['prefix' => '{campaign}'], function () {
                Route::get('edit', [CampaignController::class, 'edit'])->name('campaign.edit');
                Route::get('show', [CampaignController::class, 'show'])->name('campaign.show');
                Route::delete('/', [CampaignController::class, 'delete'])->name('campaign.delete');
                Route::delete('/delete-avatar', [CampaignController::class, 'deleteAvatar'])->name('campaign.delete.avatar');
            });
        });
    });


    Route::group([
        'prefix' => 'user',
        'as' => 'user.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [UserController::class, 'index'])->name('user.index');

            Route::get('list', [UserController::class, 'jsonList'])->name('user.jsonlist');
            Route::get('create', [UserController::class, 'create'])->name('user.create');
            Route::post('store', [UserController::class, 'store'])->name('user.store');
            Route::post('/', [UserController::class, 'update'])->name('user.update');

            Route::group(['prefix' => '{user}'], function () {
                Route::get('edit', [UserController::class, 'edit'])->name('user.edit');
                Route::get('show', [UserController::class, 'show'])->name('user.show');
                Route::delete('/', [UserController::class, 'delete'])->name('user.delete');
                Route::delete('/delete-avatar', [UserController::class, 'deleteAvatar'])->name('user.delete.avatar');
            });
        });
    });

    Route::group([
        'prefix' => 'lopd',
        'as' => 'lopd.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [LopdController::class, 'index'])->name('lopd.index');

            Route::get('create', [LopdController::class, 'create'])->name('lopd.create');
            Route::post('store', [LopdController::class, 'store'])->name('lopd.store');
            Route::post('/', [LopdController::class, 'update'])->name('lopd.update');

            Route::group(['prefix' => '{lopd}'], function () {
                Route::get('edit', [LopdController::class, 'edit'])->name('lopd.edit');
                Route::delete('/', [LopdController::class, 'delete'])->name('lopd.delete');
            });
        });
    });


    Route::group([
        'prefix' => 'announcement',
        'as' => 'announcement.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [AnnouncementController::class, 'index'])->name('announcement.index');

            Route::get('create', [AnnouncementController::class, 'create'])->name('announcement.create');
            Route::post('store', [AnnouncementController::class, 'store'])->name('announcement.store');
            Route::post('/', [AnnouncementController::class, 'update'])->name('announcement.update');

            Route::group(['prefix' => '{announcement}'], function () {
                Route::get('edit', [AnnouncementController::class, 'edit'])->name('announcement.edit');
                Route::delete('/', [AnnouncementController::class, 'delete'])->name('announcement.delete');
            });
        });
    });

    Route::group([
        'prefix' => 'hour',
        'as' => 'hour.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [HourController::class, 'index'])->name('hour.index');

            Route::get('create', [HourController::class, 'create'])->name('hour.create');
            Route::post('store', [HourController::class, 'store'])->name('hour.store');
            Route::post('search', [HourController::class, 'search'])->name('hour.search');
            Route::post('localize', [HourController::class, 'localize'])->name('hour.localize');
            Route::post('/', [HourController::class, 'update'])->name('hour.update');

            Route::delete('cancel', [HourController::class, 'process'])->name('hour.cancel');
            Route::post('accept', [HourController::class, 'process'])->name('hour.accept');

            Route::group(['prefix' => '{hour}'], function () {
                Route::get('show', [HourController::class, 'show'])->name('hour.show');
                Route::get('edit', [HourController::class, 'edit'])->name('hour.edit');
                Route::delete('/', [HourController::class, 'delete'])->name('hour.delete');
            });
        });
    });


    Route::group([
        'prefix' => 'master',
        'as' => 'master.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [MasterController::class, 'index'])->name('master.index');

            Route::post('store', [MasterController::class, 'store'])->name('master.store');
            Route::post('search', [MasterController::class, 'search'])->name('master.search');
        });
    });


    Route::group([
        'prefix' => 'message',
        'as' => 'message.',
    ], function () {
        Route::group([
            'middleware' => ['admin'],
        ], function () {
            Route::get('/', [MessageController::class, 'index'])->name('message.index');

            Route::get('create', [MessageController::class, 'create'])->name('message.create');
            Route::post('store', [MessageController::class, 'store'])->name('message.store');
            Route::post('search', [MessageController::class, 'search'])->name('message.search');
            Route::post('/', [MessageController::class, 'update'])->name('message.update');
            Route::post('select', [MessageController::class, 'process'])->name('message.select');

            Route::group(['prefix' => '{message}'], function () {
                Route::get('show', [MessageController::class, 'show'])->name('message.show');
                Route::delete('/', [MessageController::class, 'delete'])->name('message.delete');
            });
        });
    });

});
