<?php

use Illuminate\Support\Facades\Route;
use Laravel\Fortify\Features;
use App\Http\Controllers\LoginController;
use App\Http\Controllers\Front\MessageController;
use App\Http\Controllers\Front\LeadController;
use App\Http\Controllers\Front\CampaignController;

Route::group(['middleware' => ['auth', 'web']], function () {
    //Redirect
    Route::get('redirect', [LoginController::class, 'index'])->name('redirect');

    //Home
    Route::view('home', 'front.home')->name('home');

    //2FA
    if (Features::enabled(Features::twoFactorAuthentication())) {

        Route::get('/user/two-factor-authentication', function () {
            return view('auth.login');
        })->name('user.2fa');
    }

    //Messages
    Route::group([
        'prefix' => 'message',
        'as' => 'message.',
    ], function () {
        Route::get('/', [MessageController::class, 'index'])->name('message.index');
        Route::post('/search', [MessageController::class, 'search'])->name('message.search');
        Route::delete('/', [MessageController::class, 'delete'])->name('message.delete');
        Route::group(['prefix' => '{message}'], function () {
            Route::get('show', [MessageController::class, 'show'])->name('message.show');
        });
    });

    //Leads
    Route::group([
        'prefix' => 'lead',
        'as' => 'lead.',
    ], function () {
        Route::get('/', [LeadController::class, 'index'])->name('lead.index');
        Route::post('store', [LeadController::class, 'store'])->name('lead.store');
        Route::delete('/', [LeadController::class, 'delete'])->name('lead.delete');
        Route::match(array('GET','POST'), 'list', [LeadController::class, 'list'])->name('lead.list');
        Route::match(array('GET','POST'),'delega', [LeadController::class, 'delega'])->name('lead.delega');
        Route::group(['prefix' => '{lead}'], function () {
            Route::get('thanks', [LeadController::class, 'thanks'])->name('lead.thanks');
            Route::get('show', [LeadController::class, 'show'])->name('lead.show');
        });
    });

    //Campaigns
    Route::group([
        'prefix' => 'campaign',
        'as' => 'campaign.',
    ], function () {
        Route::get('/', [CampaignController::class, 'index'])->name('campaign.index');
        Route::post('change', [CampaignController::class, 'change'])->name('campaign.change');
    });
});
