const mix = require('laravel-mix');

/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your Laravel applications. By default, we are compiling the CSS
 | file for the application as well as bundling up all the JS files.
 |
 */

mix.copy('node_modules/admin-lte/plugins', 'public/plugins');
mix.copy('node_modules/admin-lte/dist/css/adminlte.min.css.map', 'public/css');
mix.js('node_modules/admin-lte/dist/js/adminlte.min.js', 'public/js').sourceMaps();
mix.styles([
    'node_modules/admin-lte/dist/css/adminlte.min.css',
], 'public/css/adminlte.min.css').sourceMaps();

mix.copyDirectory('node_modules/tinymce/icons', 'public/vendor/tinymce/icons').sourceMaps();
mix.copyDirectory('node_modules/tinymce/plugins', 'public/vendor/tinymce/plugins').sourceMaps();
mix.copyDirectory('node_modules/tinymce/skins', 'public/vendor/tinymce/skins').sourceMaps();
mix.copyDirectory('node_modules/tinymce/themes', 'public/vendor/tinymce/themes').sourceMaps();
mix.copy('node_modules/tinymce/jquery.tinymce.js', 'public/vendor/tinymce/jquery.tinymce.js').sourceMaps();
mix.copy('node_modules/tinymce/jquery.tinymce.min.js', 'public/vendor/tinymce/jquery.tinymce.min.js').sourceMaps();
mix.copy('node_modules/tinymce/tinymce.js', 'public/vendor/tinymce/tinymce.js').sourceMaps();
mix.copy('node_modules/tinymce/tinymce.min.js', 'public/vendor/tinymce/tinymce.min.js').sourceMaps();

mix.copyDirectory('resources/js/tinymce', 'public/vendor/tinymce/langs');

mix.setPublicPath('public')
    .setResourceRoot('../')
    .sass('resources/scss/app.scss', 'public/css', [
        //
    ]);

mix.js('resources/js/app.js', 'public/js')
.extract([
    // Extract packages from node_modules to vendor.js
    'jquery',
    'bootstrap',
    'popper.js',
    'axios',
    'sweetalert2',
    'lodash',
    'toastr',
    'jsvat',
])
.sourceMaps();

mix.js('resources/js/backend/company.js', 'js/backend/company.js')
    .js('resources/js/backend/entity.js', 'js/backend/entity.js')
    .js('resources/js/backend/noti.js', 'js/backend/noti.js')
    .js('resources/js/backend/announcement.js', 'js/backend/announcement.js')
    .js('resources/js/backend/user.js', 'js/backend/user.js')
    .js('resources/js/backend/lopd.js', 'js/backend/lopd.js')
    .js('resources/js/backend/search.js', 'js/backend/search.js')
    .js('resources/js/backend/master.js', 'js/backend/master.js')
    .js('resources/js/backend/bo.js', 'js/backend/bo.js')
    .js([
        'resources/js/backend/before.js',
        'resources/js/backend/app.js',
        'resources/js/backend/after.js',
    ], 'js/backend/app.js')
    .js('resources/js/front/campaign.js', 'js/front/campaign.js')
    .js('resources/js/front/login.js', 'js/front/login.js')
    .js('resources/js/front/hour.js', 'js/front/hour.js')
    .js('resources/js/front/lead.js', 'js/front/lead.js')
    .js('resources/js/front/app.js', 'js/front/app.js')
    .js('resources/js/front/2fa.js', 'js/front/2fa.js')
    .js('resources/js/common.js', 'js/common.js');


if (mix.inProduction()) {
    mix.version()
        .options({
            // Optimize JS minification process
            terser: {
                cache: true,
                parallel: true,
                sourceMap: true
            }
        });
} else {
    // Uses inline source-maps on development
    mix.webpackConfig({
        devtool: 'inline-source-map'
    });
}
